@@ -10,7 +10,7 @@ import React from 'react';
 import Button from '../Button';
 
 var DangerButton = function DangerButton(props) {
-  return React.createElement(Button, _extends({
+  return /*#__PURE__*/React.createElement(Button, _extends({
     kind: "danger"
   }, props));
 };
