@@ -1,16 +1,20 @@
+function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }
+
 var _defaultTranslations;
 
-function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }
+function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
 
-function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }
+function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
 
-function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }
+function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
 
-function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }
+function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }
+
+function _iterableToArrayLimit(arr, i) { var _i = arr && (typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]); if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }
 
 function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
 
-function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }
+function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }
 
 function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
 
@@ -24,16 +28,20 @@ function _defineProperties(target, props) { for (var i = 0; i < props.length; i+
 
 function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }
 
-function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }
-
-function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
-
-function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
-
 function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }
 
 function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
 
+function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
+
+function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }
+
+function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
+
+function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
+
+function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
+
 function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
 
 /**
@@ -47,6 +55,7 @@ import React from 'react';
 import isEqual from 'lodash.isequal';
 import getDerivedStateFromProps from './state/getDerivedStateFromProps';
 import { getNextSortState } from './state/sorting';
+import { getCellId } from './tools/cells';
 import denormalize from './tools/denormalize';
 import { composeEventHandlers } from '../../tools/events';
 import { defaultFilterRows } from './tools/filter';
@@ -80,21 +89,21 @@ var translateWithId = function translateWithId(id) {
  */
 
 
-var DataTable =
-/*#__PURE__*/
-function (_React$Component) {
+var DataTable = /*#__PURE__*/function (_React$Component) {
   _inherits(DataTable, _React$Component);
 
+  var _super = _createSuper(DataTable);
+
   function DataTable(_props) {
     var _this;
 
     _classCallCheck(this, DataTable);
 
-    _this = _possibleConstructorReturn(this, _getPrototypeOf(DataTable).call(this, _props));
+    _this = _super.call(this, _props);
 
     _defineProperty(_assertThisInitialized(_this), "getHeaderProps", function (_ref) {
       var header = _ref.header,
-          onClick = _ref.onClick,
+          _onClick = _ref.onClick,
           _ref$isSortable = _ref.isSortable,
           isSortable = _ref$isSortable === void 0 ? _this.props.isSortable : _ref$isSortable,
           rest = _objectWithoutProperties(_ref, ["header", "onClick", "isSortable"]);
@@ -102,17 +111,23 @@ function (_React$Component) {
       var _this$state = _this.state,
           sortDirection = _this$state.sortDirection,
           sortHeaderKey = _this$state.sortHeaderKey;
-      return _objectSpread({}, rest, {
+      return _objectSpread(_objectSpread({}, rest), {}, {
         key: header.key,
         sortDirection: sortDirection,
         isSortable: isSortable,
         isSortHeader: sortHeaderKey === header.key,
-        // Compose the event handlers so we don't overwrite a consumer's `onClick`
-        // handler
-        onClick: composeEventHandlers([_this.handleSortBy(header.key), onClick ? _this.handleOnHeaderClick(onClick, {
-          sortHeaderKey: header.key,
-          sortDirection: sortDirection
-        }) : null])
+        onClick: function onClick(event) {
+          var nextSortState = getNextSortState(_this.props, _this.state, {
+            key: header.key
+          });
+
+          _this.setState(nextSortState, function () {
+            _onClick && _this.handleOnHeaderClick(_onClick, {
+              sortHeaderKey: header.key,
+              sortDirection: nextSortState.sortDirection
+            })(event);
+          });
+        }
       });
     });
 
@@ -130,7 +145,7 @@ function (_React$Component) {
         return rowsById[id].isExpanded;
       });
       var translationKey = !isExpanded ? translationKeys.collapseAll : translationKeys.expandAll;
-      return _objectSpread({}, rest, {
+      return _objectSpread(_objectSpread({}, rest), {}, {
         ariaLabel: t(translationKey),
         isExpanded: isExpanded,
         // Compose the event handlers so we don't overwrite a consumer's `onClick`
@@ -160,7 +175,7 @@ function (_React$Component) {
 
       var t = _this.props.translateWithId;
       var translationKey = row.isExpanded ? translationKeys.collapseRow : translationKeys.expandRow;
-      return _objectSpread({}, rest, {
+      return _objectSpread(_objectSpread({}, rest), {}, {
         key: row.id,
         // Compose the event handlers so we don't overwrite a consumer's `onClick`
         // handler
@@ -183,7 +198,7 @@ function (_React$Component) {
       if (row) {
         var _translationKey = row.isSelected ? translationKeys.unselectRow : translationKeys.selectRow;
 
-        return _objectSpread({}, rest, {
+        return _objectSpread(_objectSpread({}, rest), {}, {
           checked: row.isSelected,
           onSelect: composeEventHandlers([_this.handleOnSelectRow(row.id), onClick]),
           id: "".concat(_this.getTablePrefix(), "__select-row-").concat(row.id),
@@ -203,7 +218,7 @@ function (_React$Component) {
       var checked = rowCount > 0 && selectedRowCount === rowCount;
       var indeterminate = rowCount > 0 && selectedRowCount > 0 && selectedRowCount !== rowCount;
       var translationKey = checked || indeterminate ? translationKeys.unselectAll : translationKeys.selectAll;
-      return _objectSpread({}, rest, {
+      return _objectSpread(_objectSpread({}, rest), {}, {
         ariaLabel: t(translationKey),
         checked: checked,
         id: "".concat(_this.getTablePrefix(), "__select-all"),
@@ -213,13 +228,23 @@ function (_React$Component) {
       });
     });
 
+    _defineProperty(_assertThisInitialized(_this), "getToolbarProps", function () {
+      var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
+      var size = _this.props.size; // Remove compact, short in V11
+
+      var isSmall = size === 'compact' || size === 'short' || size === 'xs' || size === 'sm';
+      return _objectSpread(_objectSpread({}, props), {}, {
+        size: isSmall ? 'small' : 'normal'
+      });
+    });
+
     _defineProperty(_assertThisInitialized(_this), "getBatchActionProps", function () {
       var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
       var shouldShowBatchActions = _this.state.shouldShowBatchActions;
 
       var totalSelected = _this.getSelectedRows().length;
 
-      return _objectSpread({}, props, {
+      return _objectSpread(_objectSpread({}, props), {}, {
         shouldShowBatchActions: shouldShowBatchActions,
         totalSelected: totalSelected,
         onCancel: _this.handleOnCancel
@@ -233,14 +258,16 @@ function (_React$Component) {
           isSortable = _this$props.isSortable,
           useStaticWidth = _this$props.useStaticWidth,
           shouldShowBorder = _this$props.shouldShowBorder,
-          stickyHeader = _this$props.stickyHeader;
+          stickyHeader = _this$props.stickyHeader,
+          overflowMenuOnHover = _this$props.overflowMenuOnHover;
       return {
         useZebraStyles: useZebraStyles,
         size: size,
         isSortable: isSortable,
         useStaticWidth: useStaticWidth,
         shouldShowBorder: shouldShowBorder,
-        stickyHeader: stickyHeader
+        stickyHeader: stickyHeader,
+        overflowMenuOnHover: overflowMenuOnHover
       };
     });
 
@@ -254,7 +281,7 @@ function (_React$Component) {
     _defineProperty(_assertThisInitialized(_this), "getSelectedRows", function () {
       return _this.state.rowIds.filter(function (id) {
         var row = _this.state.rowsById[id];
-        return row.isSelected;
+        return row.isSelected && !row.disabled;
       });
     });
 
@@ -263,11 +290,12 @@ function (_React$Component) {
         rowIds: _this.state.rowIds,
         headers: _this.props.headers,
         cellsById: _this.state.cellsById,
-        inputValue: _this.state.filterInputValue
+        inputValue: _this.state.filterInputValue,
+        getCellId: getCellId
       }) : _this.state.rowIds;
 
       if (filteredRowIds.length == 0) {
-        return _this.state.rowIds;
+        return [];
       }
 
       return filteredRowIds;
@@ -281,8 +309,8 @@ function (_React$Component) {
       var rowIds = initialState.rowIds;
       return {
         rowsById: rowIds.reduce(function (acc, id) {
-          return _objectSpread({}, acc, _defineProperty({}, id, _objectSpread({}, initialState.rowsById[id], {
-            isSelected: !initialState.rowsById[id].disabled && filteredRowIds.includes(id) && isSelected
+          return _objectSpread(_objectSpread({}, acc), {}, _defineProperty({}, id, _objectSpread(_objectSpread({}, initialState.rowsById[id]), !initialState.rowsById[id].disabled && {
+            isSelected: filteredRowIds.includes(id) && isSelected
           })));
         }, {})
       };
@@ -302,7 +330,7 @@ function (_React$Component) {
 
         var rowsById = state.rowsById;
         var isSelected = !(Object.values(rowsById).filter(function (row) {
-          return row.isSelected == true;
+          return row.isSelected && !row.disabled;
         }).length > 0);
         return _objectSpread({
           shouldShowBatchActions: isSelected
@@ -328,7 +356,7 @@ function (_React$Component) {
             }, {});
             return {
               shouldShowBatchActions: false,
-              rowsById: _objectSpread({}, rowsById, _defineProperty({}, rowId, _objectSpread({}, row, {
+              rowsById: _objectSpread(_objectSpread({}, rowsById), {}, _defineProperty({}, rowId, _objectSpread(_objectSpread({}, row), {}, {
                 isSelected: !row.isSelected
               })))
             };
@@ -345,7 +373,7 @@ function (_React$Component) {
             // have a non-zero number of selected rows that batch actions could
             // still apply to
             shouldShowBatchActions: !row.isSelected || selectedRowsCount > 0,
-            rowsById: _objectSpread({}, state.rowsById, _defineProperty({}, rowId, _objectSpread({}, row, {
+            rowsById: _objectSpread(_objectSpread({}, state.rowsById), {}, _defineProperty({}, rowId, _objectSpread(_objectSpread({}, row), {}, {
               isSelected: !row.isSelected
             })))
           };
@@ -360,7 +388,7 @@ function (_React$Component) {
           var isExpandedAll = state.isExpandedAll;
           return {
             isExpandedAll: row.isExpanded ? false : isExpandedAll,
-            rowsById: _objectSpread({}, state.rowsById, _defineProperty({}, rowId, _objectSpread({}, row, {
+            rowsById: _objectSpread(_objectSpread({}, state.rowsById), {}, _defineProperty({}, rowId, _objectSpread(_objectSpread({}, row), {}, {
               isExpanded: !row.isExpanded
             })))
           };
@@ -375,7 +403,7 @@ function (_React$Component) {
         return {
           isExpandedAll: !isExpandedAll,
           rowsById: rowIds.reduce(function (acc, id) {
-            return _objectSpread({}, acc, _defineProperty({}, id, _objectSpread({}, state.rowsById[id], {
+            return _objectSpread(_objectSpread({}, acc), {}, _defineProperty({}, id, _objectSpread(_objectSpread({}, state.rowsById[id]), {}, {
               isExpanded: !isExpandedAll
             })));
           }, {})
@@ -407,7 +435,7 @@ function (_React$Component) {
       }
     });
 
-    _this.state = _objectSpread({}, getDerivedStateFromProps(_props, {}), {
+    _this.state = _objectSpread(_objectSpread({}, getDerivedStateFromProps(_props, {})), {}, {
       isExpandedAll: false // Start with collapsed state, treat `undefined` as neutral state
 
     });
@@ -416,39 +444,45 @@ function (_React$Component) {
   }
 
   _createClass(DataTable, [{
-    key: "UNSAFE_componentWillReceiveProps",
-    value: function UNSAFE_componentWillReceiveProps(nextProps) {
+    key: "componentDidUpdate",
+    value: function componentDidUpdate(prevProps) {
+      var _this2 = this;
+
+      if (prevProps === this.props) {
+        return;
+      }
+
+      var prevRowIds = prevProps.rows.map(function (row) {
+        return row.id;
+      });
       var rowIds = this.props.rows.map(function (row) {
         return row.id;
       });
-      var nextRowIds = nextProps.rows.map(function (row) {
-        return row.id;
-      });
 
-      if (!isEqual(rowIds, nextRowIds)) {
+      if (!isEqual(prevRowIds, rowIds)) {
         this.setState(function (state) {
-          return getDerivedStateFromProps(nextProps, state);
+          return getDerivedStateFromProps(_this2.props, state);
         });
         return;
       }
 
+      var prevHeaders = prevProps.headers.map(function (header) {
+        return header.key;
+      });
       var headers = this.props.headers.map(function (header) {
         return header.key;
       });
-      var nextHeaders = nextProps.headers.map(function (header) {
-        return header.key;
-      });
 
-      if (!isEqual(headers, nextHeaders)) {
+      if (!isEqual(prevHeaders, headers)) {
         this.setState(function (state) {
-          return getDerivedStateFromProps(nextProps, state);
+          return getDerivedStateFromProps(_this2.props, state);
         });
         return;
       }
 
-      if (!isEqual(this.props.rows, nextProps.rows)) {
+      if (!isEqual(prevProps.rows, this.props.rows)) {
         this.setState(function (state) {
-          return getDerivedStateFromProps(nextProps, state);
+          return getDerivedStateFromProps(_this2.props, state);
         });
         return;
       }
@@ -460,14 +494,16 @@ function (_React$Component) {
      * @param {object} config
      * @param {string} config.header the header we want the props for
      * @param {Function} config.onClick a custom click handler for the header
+     * @param {boolean} config.isSortable
      * @returns {object}
      */
 
   }, {
     key: "render",
     value: function render() {
-      var _this2 = this;
+      var _this3 = this;
 
+      // eslint-disable-next-line react/prop-types
       var _this$props2 = this.props,
           children = _this$props2.children,
           filterRows = _this$props2.filterRows,
@@ -482,7 +518,8 @@ function (_React$Component) {
         rowIds: rowIds,
         headers: headers,
         cellsById: cellsById,
-        inputValue: filterInputValue
+        inputValue: filterInputValue,
+        getCellId: getCellId
       }) : rowIds;
       var renderProps = {
         // Data derived from state
@@ -494,6 +531,7 @@ function (_React$Component) {
         getExpandHeaderProps: this.getExpandHeaderProps,
         getRowProps: this.getRowProps,
         getSelectionProps: this.getSelectionProps,
+        getToolbarProps: this.getToolbarProps,
         getBatchActionProps: this.getBatchActionProps,
         getTableProps: this.getTableProps,
         getTableContainerProps: this.getTableContainerProps,
@@ -501,14 +539,14 @@ function (_React$Component) {
         onInputChange: this.handleOnInputValueChange,
         // Expose internal state change actions
         sortBy: function sortBy(headerKey) {
-          return _this2.handleSortBy(headerKey)();
+          return _this3.handleSortBy(headerKey)();
         },
         selectAll: this.handleSelectAll,
         selectRow: function selectRow(rowId) {
-          return _this2.handleOnSelectRow(rowId)();
+          return _this3.handleOnSelectRow(rowId)();
         },
         expandRow: function expandRow(rowId) {
-          return _this2.handleOnExpandRow(rowId)();
+          return _this3.handleOnExpandRow(rowId)();
         },
         expandAll: this.handleOnExpandAll,
         radio: this.props.radio
@@ -531,17 +569,10 @@ function (_React$Component) {
 
 _defineProperty(DataTable, "propTypes", {
   /**
-   * The `rows` prop is where you provide us with a list of all the rows that
-   * you want to render in the table. The only hard requirement is that this
-   * is an array of objects, and that each object has a unique `id` field
-   * available on it.
+   * Optional hook to manually control filtering of the rows from the
+   * TableToolbarSearch component
    */
-  rows: PropTypes.arrayOf(PropTypes.shape({
-    id: PropTypes.string.isRequired,
-    disabled: PropTypes.bool,
-    isSelected: PropTypes.bool,
-    isExpanded: PropTypes.bool
-  })).isRequired,
+  filterRows: PropTypes.func,
 
   /**
    * The `headers` prop represents the order in which the headers should
@@ -555,21 +586,60 @@ _defineProperty(DataTable, "propTypes", {
   })).isRequired,
 
   /**
-   * Optional hook to manually control sorting of the rows.
+   * Specify whether the table should be able to be sorted by its headers
    */
-  sortRow: PropTypes.func,
-
-  /**
-   * Optional hook to manually control filtering of the rows from the
-   * TableToolbarSearch component
-   */
-  filterRows: PropTypes.func,
+  isSortable: PropTypes.bool,
 
   /**
    * Provide a string for the current locale
    */
   locale: PropTypes.string,
 
+  /**
+   * Specify whether the overflow menu (if it exists) should be shown always, or only on hover
+   */
+  overflowMenuOnHover: PropTypes.bool,
+
+  /**
+   * Specify whether the control should be a radio button or inline checkbox
+   */
+  radio: PropTypes.bool,
+
+  /**
+   * The `rows` prop is where you provide us with a list of all the rows that
+   * you want to render in the table. The only hard requirement is that this
+   * is an array of objects, and that each object has a unique `id` field
+   * available on it.
+   */
+  rows: PropTypes.arrayOf(PropTypes.shape({
+    id: PropTypes.string.isRequired,
+    disabled: PropTypes.bool,
+    isSelected: PropTypes.bool,
+    isExpanded: PropTypes.bool
+  })).isRequired,
+
+  /**
+   * `false` If true, will remove the table border
+   */
+  shouldShowBorder: PropTypes.bool,
+
+  /**
+   *  Change the row height of table. Currently supports `xs`, `sm`, `md`, `lg`, and `xl`.
+   *  The previous terms (`compact`, `short`, `normal`, and `tall`) will be removed in the next major release.
+   */
+  size: PropTypes.oneOf(['compact', 'short', 'normal', 'tall', 'xs', 'sm', 'md', 'lg', 'xl']),
+
+  /**
+   * Optional hook to manually control sorting of the rows.
+   */
+  sortRow: PropTypes.func,
+
+  /**
+   * Specify whether the header should be sticky.
+   * Still experimental: may not work with every combination of table props
+   */
+  stickyHeader: PropTypes.bool,
+
   /**
    * Optional method that takes in a message id and returns an
    * internationalized string. See `DataTable.translationKeys` for all
@@ -578,26 +648,22 @@ _defineProperty(DataTable, "propTypes", {
   translateWithId: PropTypes.func,
 
   /**
-   * Specify whether the control should be a radio button or inline checkbox
+   * `false` If true, will use a width of 'auto' instead of 100%
    */
-  radio: PropTypes.bool,
+  useStaticWidth: PropTypes.bool,
 
   /**
-   * Specify whether the header should be sticky.
-   * Still experimental: may not work with every combination of table props
+   * `true` to add useZebraStyles striping.
    */
-  stickyHeader: PropTypes.bool,
-
-  /**
-   * Specify whether the table should be able to be sorted by its headers
-   */
-  isSortable: PropTypes.bool
+  useZebraStyles: PropTypes.bool
 });
 
 _defineProperty(DataTable, "defaultProps", {
   sortRow: defaultSortRow,
   filterRows: defaultFilterRows,
   locale: 'en',
+  size: 'normal',
+  overflowMenuOnHover: true,
   translateWithId: translateWithId
 });
 
