@@ -4,7 +4,7 @@
  * This source code is licensed under the Apache-2.0 license found in the
  * LICENSE file in the root directory of this source tree.
  */
-import { getCellId } from './cells';
+
 /**
  * Default implemention of how we filter rows internally. The idea behind this
  * implementation is to use the given list of row ids and headers to get the
@@ -16,19 +16,24 @@ import { getCellId } from './cells';
  * @param {Array<object>} config.headers
  * @param {object} config.cellsById object containing a map of cell id to cell
  * @param {string} config.inputValue the current input value in the Table Search
+ * @param {Function} config.getCellId
  * @returns {Array<string>} rowIds
  */
-
 export var defaultFilterRows = function defaultFilterRows(_ref) {
   var rowIds = _ref.rowIds,
       headers = _ref.headers,
       cellsById = _ref.cellsById,
-      inputValue = _ref.inputValue;
+      inputValue = _ref.inputValue,
+      getCellId = _ref.getCellId;
   return rowIds.filter(function (rowId) {
     return headers.some(function (_ref2) {
       var key = _ref2.key;
       var id = getCellId(rowId, key);
-      if (typeof cellsById[id].value === 'boolean') return false;
+
+      if (typeof cellsById[id].value === 'boolean') {
+        return false;
+      }
+
       return ('' + cellsById[id].value).toLowerCase().includes(inputValue.toLowerCase());
     });
   });
