@@ -5,5 +5,6 @@
  * LICENSE file in the root directory of this source tree.
  */
 import PropTypes from 'prop-types';
-export var ListBoxType = PropTypes.oneOf(['default', 'inline']);
-export var ListBoxSize = PropTypes.oneOf(['sm', 'xl']);
\ No newline at end of file
+export var ListBoxType = PropTypes.oneOf(['default', 'inline']); // TODO V11: remove xl
+
+export var ListBoxSize = PropTypes.oneOf(['sm', 'md', 'lg', 'xl']);
\ No newline at end of file
