@@ -1,8 +1,14 @@
-function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }
+var _iconTypes;
 
-function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }
+function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
 
-function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }
+function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
+
+function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
+
+function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }
+
+function _iterableToArrayLimit(arr, i) { var _i = arr && (typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]); if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }
 
 function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
 
@@ -21,10 +27,10 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
  * LICENSE file in the root directory of this source tree.
  */
 import PropTypes from 'prop-types';
-import React, { useState, useEffect } from 'react';
+import React, { useEffect, useRef, useState } from 'react';
 import cx from 'classnames';
 import { settings } from 'carbon-components';
-import { Close20, ErrorFilled20, CheckmarkFilled20, WarningFilled20, InformationFilled20 } from '@carbon/icons-react';
+import { Close20, ErrorFilled20, CheckmarkFilled20, WarningFilled20, WarningAltFilled20, InformationFilled20, InformationSquareFilled20 } from '@carbon/icons-react';
 import Button from '../Button';
 var prefix = settings.prefix;
 export function NotificationActionButton(_ref) {
@@ -34,7 +40,7 @@ export function NotificationActionButton(_ref) {
       rest = _objectWithoutProperties(_ref, ["children", "className", "onClick"]);
 
   var className = cx(customClassName, "".concat(prefix, "--inline-notification__action-button"));
-  return React.createElement(Button, _extends({
+  return /*#__PURE__*/React.createElement(Button, _extends({
     className: className,
     kind: "ghost",
     onClick: onClick,
@@ -42,24 +48,22 @@ export function NotificationActionButton(_ref) {
   }, rest), children);
 }
 NotificationActionButton.propTypes = {
-  /**
-   * Specify an optional className to be applied to the notification action button
-   */
-  className: PropTypes.string,
-
   /**
    * Specify the content of the notification action button.
    */
   children: PropTypes.node,
 
+  /**
+   * Specify an optional className to be applied to the notification action button
+   */
+  className: PropTypes.string,
+
   /**
    * Optionally specify a click handler for the notification action button.
    */
   onClick: PropTypes.func
 };
 export function NotificationButton(_ref2) {
-  var _cx, _cx2;
-
   var ariaLabel = _ref2.ariaLabel,
       className = _ref2.className,
       iconDescription = _ref2.iconDescription,
@@ -69,46 +73,36 @@ export function NotificationButton(_ref2) {
       notificationType = _ref2.notificationType,
       rest = _objectWithoutProperties(_ref2, ["ariaLabel", "className", "iconDescription", "type", "renderIcon", "name", "notificationType"]);
 
-  var buttonClassName = cx(className, (_cx = {}, _defineProperty(_cx, "".concat(prefix, "--toast-notification__close-button"), notificationType === 'toast'), _defineProperty(_cx, "".concat(prefix, "--inline-notification__close-button"), notificationType === 'inline'), _cx));
-  var iconClassName = cx((_cx2 = {}, _defineProperty(_cx2, "".concat(prefix, "--toast-notification__close-icon"), notificationType === 'toast'), _defineProperty(_cx2, "".concat(prefix, "--inline-notification__close-icon"), notificationType === 'inline'), _cx2));
-  return React.createElement("button", _extends({}, rest, {
+  var buttonClassName = cx(className, _defineProperty({}, "".concat(prefix, "--").concat(notificationType, "-notification__close-button"), notificationType));
+  var iconClassName = cx(_defineProperty({}, "".concat(prefix, "--").concat(notificationType, "-notification__close-icon"), notificationType));
+  return /*#__PURE__*/React.createElement("button", _extends({}, rest, {
+    // eslint-disable-next-line react/button-has-type
     type: type,
     "aria-label": iconDescription,
     title: iconDescription,
     className: buttonClassName
-  }), IconTag && React.createElement(IconTag, {
+  }), IconTag && /*#__PURE__*/React.createElement(IconTag, {
     "aria-label": ariaLabel,
     className: iconClassName,
     name: name
   }));
 }
 NotificationButton.propTypes = {
-  /**
-   * Specify an optional className to be applied to the notification button
-   */
-  className: PropTypes.string,
-
   /**
    * Specify a label to be read by screen readers on the notification button
    */
   ariaLabel: PropTypes.string,
 
   /**
-   * Optional prop to specify the type of the Button
+   * Specify an optional className to be applied to the notification button
    */
-  type: PropTypes.string,
+  className: PropTypes.string,
 
   /**
    * Provide a description for "close" icon that can be read by screen readers
    */
   iconDescription: PropTypes.string,
 
-  /**
-   * Optional prop to allow overriding the icon rendering.
-   * Can be a React component class
-   */
-  renderIcon: PropTypes.oneOfType([PropTypes.func, PropTypes.object]),
-
   /**
    * Specify an optional icon for the Button through a string,
    * if something but regular "close" icon is desirable
@@ -118,7 +112,18 @@ NotificationButton.propTypes = {
   /**
    * Specify the notification type
    */
-  notificationType: PropTypes.oneOf(['toast', 'inline'])
+  notificationType: PropTypes.oneOf(['toast', 'inline']),
+
+  /**
+   * Optional prop to allow overriding the icon rendering.
+   * Can be a React component class
+   */
+  renderIcon: PropTypes.oneOfType([PropTypes.func, PropTypes.object]),
+
+  /**
+   * Optional prop to specify the type of the Button
+   */
+  type: PropTypes.string
 };
 NotificationButton.defaultProps = {
   ariaLabel: 'close notification',
@@ -137,37 +142,42 @@ export function NotificationTextDetails(_ref3) {
       rest = _objectWithoutProperties(_ref3, ["title", "subtitle", "caption", "notificationType", "children"]);
 
   if (notificationType === 'toast') {
-    return React.createElement("div", _extends({}, rest, {
+    return /*#__PURE__*/React.createElement("div", _extends({}, rest, {
       className: "".concat(prefix, "--toast-notification__details")
-    }), React.createElement("h3", {
+    }), /*#__PURE__*/React.createElement("h3", {
       className: "".concat(prefix, "--toast-notification__title")
-    }, title), React.createElement("div", {
+    }, title), /*#__PURE__*/React.createElement("div", {
       className: "".concat(prefix, "--toast-notification__subtitle")
-    }, subtitle), React.createElement("div", {
+    }, subtitle), caption && /*#__PURE__*/React.createElement("div", {
       className: "".concat(prefix, "--toast-notification__caption")
     }, caption), children);
   }
 
   if (notificationType === 'inline') {
-    return React.createElement("div", _extends({}, rest, {
+    return /*#__PURE__*/React.createElement("div", _extends({}, rest, {
       className: "".concat(prefix, "--inline-notification__text-wrapper")
-    }), React.createElement("p", {
+    }), /*#__PURE__*/React.createElement("p", {
       className: "".concat(prefix, "--inline-notification__title")
-    }, title), React.createElement("div", {
+    }, title), /*#__PURE__*/React.createElement("div", {
       className: "".concat(prefix, "--inline-notification__subtitle")
     }, subtitle), children);
   }
 }
 NotificationTextDetails.propTypes = {
+  /**
+   * Specify the caption
+   */
+  caption: PropTypes.node,
+
   /**
    * Pass in the children that will be rendered in NotificationTextDetails
    */
   children: PropTypes.node,
 
   /**
-   * Specify the title
+   * Specify the notification type
    */
-  title: PropTypes.string,
+  notificationType: PropTypes.oneOf(['toast', 'inline']),
 
   /**
    * Specify the sub-title
@@ -175,26 +185,19 @@ NotificationTextDetails.propTypes = {
   subtitle: PropTypes.node,
 
   /**
-   * Specify the caption
+   * Specify the title
    */
-  caption: PropTypes.node,
-
-  /**
-   * Specify the notification type
-   */
-  notificationType: PropTypes.oneOf(['toast', 'inline'])
+  title: PropTypes.string
 };
 NotificationTextDetails.defaultProps = {
   title: 'title',
-  caption: 'caption',
   notificationType: 'toast'
 };
-var iconTypes = {
+var iconTypes = (_iconTypes = {
   error: ErrorFilled20,
   success: CheckmarkFilled20,
-  warning: WarningFilled20,
-  info: InformationFilled20
-};
+  warning: WarningFilled20
+}, _defineProperty(_iconTypes, 'warning-alt', WarningAltFilled20), _defineProperty(_iconTypes, "info", InformationFilled20), _defineProperty(_iconTypes, 'info-square', InformationSquareFilled20), _iconTypes);
 
 function NotificationIcon(_ref4) {
   var iconDescription = _ref4.iconDescription,
@@ -206,21 +209,22 @@ function NotificationIcon(_ref4) {
     return null;
   }
 
-  return React.createElement(IconForKind, {
+  return /*#__PURE__*/React.createElement(IconForKind, {
     className: "".concat(prefix, "--").concat(notificationType, "-notification__icon")
-  }, React.createElement("title", null, iconDescription));
+  }, /*#__PURE__*/React.createElement("title", null, iconDescription));
 }
 
 NotificationIcon.propTypes = {
-  notificationType: PropTypes.oneOf(['inline', 'toast']).isRequired,
-  kind: PropTypes.oneOf(['error', 'success', 'warning', 'info']).isRequired,
-  iconDescription: PropTypes.string.isRequired
+  iconDescription: PropTypes.string.isRequired,
+  kind: PropTypes.oneOf(['error', 'success', 'warning', 'warning-alt', 'info', 'info-square']).isRequired,
+  notificationType: PropTypes.oneOf(['inline', 'toast']).isRequired
 };
 export function ToastNotification(_ref5) {
   var _cx3;
 
   var role = _ref5.role,
       notificationType = _ref5.notificationType,
+      onClose = _ref5.onClose,
       onCloseButtonClick = _ref5.onCloseButtonClick,
       iconDescription = _ref5.iconDescription,
       statusIconDescription = _ref5.statusIconDescription,
@@ -233,7 +237,7 @@ export function ToastNotification(_ref5) {
       hideCloseButton = _ref5.hideCloseButton,
       children = _ref5.children,
       timeout = _ref5.timeout,
-      rest = _objectWithoutProperties(_ref5, ["role", "notificationType", "onCloseButtonClick", "iconDescription", "statusIconDescription", "className", "caption", "subtitle", "title", "kind", "lowContrast", "hideCloseButton", "children", "timeout"]);
+      rest = _objectWithoutProperties(_ref5, ["role", "notificationType", "onClose", "onCloseButtonClick", "iconDescription", "statusIconDescription", "className", "caption", "subtitle", "title", "kind", "lowContrast", "hideCloseButton", "children", "timeout"]);
 
   var _useState = useState(true),
       _useState2 = _slicedToArray(_useState, 2),
@@ -242,49 +246,67 @@ export function ToastNotification(_ref5) {
 
   var containerClassName = cx(className, (_cx3 = {}, _defineProperty(_cx3, "".concat(prefix, "--toast-notification"), true), _defineProperty(_cx3, "".concat(prefix, "--toast-notification--low-contrast"), lowContrast), _defineProperty(_cx3, "".concat(prefix, "--toast-notification--").concat(kind), kind), _cx3));
 
+  var handleClose = function handleClose(evt) {
+    if (!onClose || onClose(evt) !== false) {
+      setIsOpen(false);
+    }
+  };
+
   function handleCloseButtonClick(event) {
-    setIsOpen(false);
     onCloseButtonClick(event);
+    handleClose(event);
   }
 
+  var savedOnClose = useRef(onClose);
+  useEffect(function () {
+    savedOnClose.current = onClose;
+  });
   useEffect(function () {
     if (!timeout) {
       return;
     }
 
-    var timeoutId = window.setTimeout(function () {
+    var timeoutId = window.setTimeout(function (event) {
       setIsOpen(false);
-      onCloseButtonClick(event);
+
+      if (savedOnClose.current) {
+        savedOnClose.current(event);
+      }
     }, timeout);
     return function () {
       window.clearTimeout(timeoutId);
     };
-  }, [onCloseButtonClick, timeout]);
+  }, [timeout]);
 
   if (!isOpen) {
     return null;
   }
 
-  return React.createElement("div", _extends({}, rest, {
+  return /*#__PURE__*/React.createElement("div", _extends({}, rest, {
     role: role,
     kind: kind,
     className: containerClassName
-  }), React.createElement(NotificationIcon, {
+  }), /*#__PURE__*/React.createElement(NotificationIcon, {
     notificationType: notificationType,
     kind: kind,
     iconDescription: statusIconDescription || "".concat(kind, " icon")
-  }), React.createElement(NotificationTextDetails, {
+  }), /*#__PURE__*/React.createElement(NotificationTextDetails, {
     title: title,
     subtitle: subtitle,
     caption: caption,
     notificationType: notificationType
-  }, children), !hideCloseButton && React.createElement(NotificationButton, {
+  }, children), !hideCloseButton && /*#__PURE__*/React.createElement(NotificationButton, {
     iconDescription: iconDescription,
     notificationType: notificationType,
     onClick: handleCloseButtonClick
   }));
 }
 ToastNotification.propTypes = {
+  /**
+   * Specify the caption
+   */
+  caption: PropTypes.node,
+
   /**
    * Pass in the children that will be rendered within the ToastNotification
    */
@@ -295,52 +317,26 @@ ToastNotification.propTypes = {
    */
   className: PropTypes.string,
 
+  /**
+   * Specify the close button should be disabled, or not
+   */
+  hideCloseButton: PropTypes.bool,
+
+  /**
+   * Provide a description for "close" icon that can be read by screen readers
+   */
+  iconDescription: PropTypes.string,
+
   /**
    * Specify what state the notification represents
    */
-  kind: PropTypes.oneOf(['error', 'info', 'success', 'warning']).isRequired,
+  kind: PropTypes.oneOf(['error', 'info', 'info-square', 'success', 'warning', 'warning-alt']).isRequired,
 
   /**
    * Specify whether you are using the low contrast variant of the ToastNotification.
    */
   lowContrast: PropTypes.bool,
 
-  /**
-   * Specify the title
-   */
-  title: PropTypes.string.isRequired,
-
-  /**
-   * Specify the sub-title
-   */
-  subtitle: PropTypes.node,
-
-  /**
-   * By default, this value is "alert". You can also provide an alternate
-   * role if it makes sense from the accessibility-side
-   */
-  role: PropTypes.string.isRequired,
-
-  /**
-   * Specify the caption
-   */
-  caption: PropTypes.node,
-
-  /**
-   * Provide a function that is called when menu is closed
-   */
-  onCloseButtonClick: PropTypes.func,
-
-  /**
-   * Provide a description for "close" icon that can be read by screen readers
-   */
-  iconDescription: PropTypes.string.isRequired,
-
-  /**
-   * Provide a description for "status" icon that can be read by screen readers
-   */
-  statusIconDescription: PropTypes.string.isRequired,
-
   /**
    * By default, this value is "toast". You can also provide an alternate type
    * if it makes sense for the underlying `<NotificationTextDetails>` and `<NotificationButton>`
@@ -348,19 +344,44 @@ ToastNotification.propTypes = {
   notificationType: PropTypes.string,
 
   /**
-   * Specify the close button should be disabled, or not
+   * Provide a function that is called when menu is closed
    */
-  hideCloseButton: PropTypes.bool,
+  onClose: PropTypes.func,
+
+  /**
+   * Provide a function that is called when the close button is clicked
+   */
+  onCloseButtonClick: PropTypes.func,
+
+  /**
+   * By default, this value is "alert". You can also provide an alternate
+   * role if it makes sense from the accessibility-side
+   */
+  role: PropTypes.string.isRequired,
+
+  /**
+   * Provide a description for "status" icon that can be read by screen readers
+   */
+  statusIconDescription: PropTypes.string,
+
+  /**
+   * Specify the sub-title
+   */
+  subtitle: PropTypes.node,
 
   /**
    * Specify an optional duration the notification should be closed in
    */
-  timeout: PropTypes.number
+  timeout: PropTypes.number,
+
+  /**
+   * Specify the title
+   */
+  title: PropTypes.string.isRequired
 };
 ToastNotification.defaultProps = {
   kind: 'error',
   title: 'provide a title',
-  caption: 'provide a caption',
   role: 'alert',
   notificationType: 'toast',
   iconDescription: 'closes notification',
@@ -374,6 +395,7 @@ export function InlineNotification(_ref6) {
   var actions = _ref6.actions,
       role = _ref6.role,
       notificationType = _ref6.notificationType,
+      onClose = _ref6.onClose,
       onCloseButtonClick = _ref6.onCloseButtonClick,
       iconDescription = _ref6.iconDescription,
       statusIconDescription = _ref6.statusIconDescription,
@@ -384,7 +406,7 @@ export function InlineNotification(_ref6) {
       lowContrast = _ref6.lowContrast,
       hideCloseButton = _ref6.hideCloseButton,
       children = _ref6.children,
-      rest = _objectWithoutProperties(_ref6, ["actions", "role", "notificationType", "onCloseButtonClick", "iconDescription", "statusIconDescription", "className", "subtitle", "title", "kind", "lowContrast", "hideCloseButton", "children"]);
+      rest = _objectWithoutProperties(_ref6, ["actions", "role", "notificationType", "onClose", "onCloseButtonClick", "iconDescription", "statusIconDescription", "className", "subtitle", "title", "kind", "lowContrast", "hideCloseButton", "children"]);
 
   var _useState3 = useState(true),
       _useState4 = _slicedToArray(_useState3, 2),
@@ -393,30 +415,36 @@ export function InlineNotification(_ref6) {
 
   var containerClassName = cx(className, (_cx4 = {}, _defineProperty(_cx4, "".concat(prefix, "--inline-notification"), true), _defineProperty(_cx4, "".concat(prefix, "--inline-notification--low-contrast"), lowContrast), _defineProperty(_cx4, "".concat(prefix, "--inline-notification--").concat(kind), kind), _defineProperty(_cx4, "".concat(prefix, "--inline-notification--hide-close-button"), hideCloseButton), _cx4));
 
+  var handleClose = function handleClose(evt) {
+    if (!onClose || onClose(evt) !== false) {
+      setIsOpen(false);
+    }
+  };
+
   function handleCloseButtonClick(event) {
-    setIsOpen(false);
     onCloseButtonClick(event);
+    handleClose(event);
   }
 
   if (!isOpen) {
     return null;
   }
 
-  return React.createElement("div", _extends({}, rest, {
+  return /*#__PURE__*/React.createElement("div", _extends({}, rest, {
     role: role,
     kind: kind,
     className: containerClassName
-  }), React.createElement("div", {
+  }), /*#__PURE__*/React.createElement("div", {
     className: "".concat(prefix, "--inline-notification__details")
-  }, React.createElement(NotificationIcon, {
+  }, /*#__PURE__*/React.createElement(NotificationIcon, {
     notificationType: notificationType,
     kind: kind,
     iconDescription: statusIconDescription || "".concat(kind, " icon")
-  }), React.createElement(NotificationTextDetails, {
+  }), /*#__PURE__*/React.createElement(NotificationTextDetails, {
     title: title,
     subtitle: subtitle,
     notificationType: notificationType
-  }, children)), actions, !hideCloseButton && React.createElement(NotificationButton, {
+  }, children)), actions, !hideCloseButton && /*#__PURE__*/React.createElement(NotificationButton, {
     iconDescription: iconDescription,
     notificationType: notificationType,
     onClick: handleCloseButtonClick
@@ -438,47 +466,26 @@ InlineNotification.propTypes = {
    */
   className: PropTypes.string,
 
+  /**
+   * Specify the close button should be disabled, or not
+   */
+  hideCloseButton: PropTypes.bool,
+
+  /**
+   * Provide a description for "close" icon that can be read by screen readers
+   */
+  iconDescription: PropTypes.string,
+
   /**
    * Specify what state the notification represents
    */
-  kind: PropTypes.oneOf(['error', 'info', 'success', 'warning']).isRequired,
+  kind: PropTypes.oneOf(['error', 'info', 'info-square', 'success', 'warning', 'warning-alt']).isRequired,
 
   /**
    * Specify whether you are using the low contrast variant of the InlineNotification.
    */
   lowContrast: PropTypes.bool,
 
-  /**
-   * Specify the title
-   */
-  title: PropTypes.string.isRequired,
-
-  /**
-   * Specify the sub-title
-   */
-  subtitle: PropTypes.node,
-
-  /**
-   * By default, this value is "alert". You can also provide an alternate
-   * role if it makes sense from the accessibility-side
-   */
-  role: PropTypes.string.isRequired,
-
-  /**
-   * Provide a function that is called when menu is closed
-   */
-  onCloseButtonClick: PropTypes.func,
-
-  /**
-   * Provide a description for "close" icon that can be read by screen readers
-   */
-  iconDescription: PropTypes.string.isRequired,
-
-  /**
-   * Provide a description for "status" icon that can be read by screen readers
-   */
-  statusIconDescription: PropTypes.string.isRequired,
-
   /**
    * By default, this value is "inline". You can also provide an alternate type
    * if it makes sense for the underlying `<NotificationTextDetails>` and `<NotificationButton>`
@@ -486,9 +493,35 @@ InlineNotification.propTypes = {
   notificationType: PropTypes.string,
 
   /**
-   * Specify the close button should be disabled, or not
+   * Provide a function that is called when menu is closed
    */
-  hideCloseButton: PropTypes.bool
+  onClose: PropTypes.func,
+
+  /**
+   * Provide a function that is called when the close button is clicked
+   */
+  onCloseButtonClick: PropTypes.func,
+
+  /**
+   * By default, this value is "alert". You can also provide an alternate
+   * role if it makes sense from the accessibility-side
+   */
+  role: PropTypes.string.isRequired,
+
+  /**
+   * Provide a description for "status" icon that can be read by screen readers
+   */
+  statusIconDescription: PropTypes.string,
+
+  /**
+   * Specify the sub-title
+   */
+  subtitle: PropTypes.node,
+
+  /**
+   * Specify the title
+   */
+  title: PropTypes.string.isRequired
 };
 InlineNotification.defaultProps = {
   role: 'alert',
