@@ -6,7 +6,7 @@
  */
 import React from 'react';
 import { mount, shallow } from 'enzyme';
-import { CaretDownGlyph, CaretUpGlyph } from '@carbon/icons-react';
+import { Subtract16, Add16 } from '@carbon/icons-react';
 import NumberInput from '../NumberInput';
 import NumberInputSkeleton from '../NumberInput/NumberInput.Skeleton';
 import { settings } from 'carbon-components';
@@ -40,8 +40,8 @@ describe('NumberInput', function () {
           return undefined;
         }
       };
-      wrapper = mount(React.createElement(NumberInput, mockProps));
-      var iconTypes = [CaretDownGlyph, CaretUpGlyph];
+      wrapper = mount( /*#__PURE__*/React.createElement(NumberInput, mockProps));
+      var iconTypes = [Subtract16, Add16];
       label = wrapper.find('label');
       numberInput = wrapper.find('input');
       container = wrapper.find(".".concat(prefix, "--number"));
@@ -136,7 +136,7 @@ describe('NumberInput', function () {
       });
       describe('initial rendering', function () {
         var getWrapper = function getWrapper(min, max, value) {
-          return mount(React.createElement(NumberInput, {
+          return mount( /*#__PURE__*/React.createElement(NumberInput, {
             min: min,
             max: max,
             value: value,
@@ -150,6 +150,19 @@ describe('NumberInput', function () {
           return wrapper.find('input');
         };
 
+        it('should correctly set defaultValue on uncontrolled input', function () {
+          var wrapper = mount( /*#__PURE__*/React.createElement(NumberInput, {
+            min: -1,
+            max: 100,
+            defaultValue: 10,
+            id: "test",
+            label: "Number Input",
+            className: "extra-class"
+          }));
+          var numberInput = getNumberInput(wrapper);
+          expect(wrapper.find('NumberInput').instance().state.value).toEqual(10);
+          expect(numberInput.prop('value')).toEqual(10);
+        });
         it('should set value as expected when value > min', function () {
           var wrapper = getWrapper(-1, 100, 0);
           var numberInput = getNumberInput(wrapper);
@@ -282,8 +295,8 @@ describe('NumberInput', function () {
         expect(wrapper.find('NumberInput').prop('iconDescription')).toEqual('choose a number');
       });
       it('should use correct icons', function () {
-        expect(icons.at(0).type()).toBe(CaretUpGlyph);
-        expect(icons.at(1).type()).toBe(CaretDownGlyph);
+        expect(icons.at(0).type()).toBe(Subtract16);
+        expect(icons.at(1).type()).toBe(Add16);
       });
       it('adds new iconDescription when passed via props', function () {
         wrapper.setProps({
@@ -313,14 +326,10 @@ describe('NumberInput', function () {
       });
       it('renders children as expected', function () {
         wrapper.setProps({
-          helperText: React.createElement("span", null, "This helper text has ", React.createElement("a", {
-            href: "#"
-          }, "a link"), ".")
+          helperText: /*#__PURE__*/React.createElement("span", null, "This is helper text.")
         });
         var renderedHelper = wrapper.find(".".concat(prefix, "--form__helper-text"));
-        expect(renderedHelper.props().children).toEqual(React.createElement("span", null, "This helper text has ", React.createElement("a", {
-          href: "#"
-        }, "a link"), "."));
+        expect(renderedHelper.props().children).toEqual( /*#__PURE__*/React.createElement("span", null, "This is helper text."));
       });
       it('should set helper text as expected', function () {
         wrapper.setProps({
@@ -334,7 +343,7 @@ describe('NumberInput', function () {
     describe('disabled numberInput', function () {
       var onClick = jest.fn();
       var onChange = jest.fn();
-      var wrapper = mount(React.createElement(NumberInput, {
+      var wrapper = mount( /*#__PURE__*/React.createElement(NumberInput, {
         id: "test",
         onClick: onClick,
         onChange: onChange,
@@ -370,7 +379,7 @@ describe('NumberInput', function () {
       beforeEach(function () {
         onClick = jest.fn();
         onChange = jest.fn();
-        wrapper = mount(React.createElement(NumberInput, {
+        wrapper = mount( /*#__PURE__*/React.createElement(NumberInput, {
           id: "test",
           onClick: onClick,
           onChange: onChange,
@@ -378,17 +387,20 @@ describe('NumberInput', function () {
           max: 100
         }));
         input = wrapper.find('input');
-        upArrow = wrapper.find(CaretUpGlyph).closest('button');
-        downArrow = wrapper.find(CaretDownGlyph).closest('button');
+        upArrow = wrapper.find(Add16).closest('button');
+        downArrow = wrapper.find(Subtract16).closest('button');
       });
       it('should invoke onClick when numberInput is clicked', function () {
         input.simulate('click');
         expect(onClick).toBeCalled();
       });
       it('should invoke onClick when up arrow is clicked', function () {
+        wrapper.setProps({
+          value: 1
+        });
         upArrow.simulate('click');
         expect(onClick).toBeCalled();
-        expect(onClick).toHaveBeenCalledWith(expect.anything(), 'up');
+        expect(onClick).toHaveBeenCalledWith(expect.anything(), 'up', 2);
       });
       it('should only increase the value on up arrow click if value is less than max', function () {
         wrapper.setProps({
@@ -441,19 +453,19 @@ describe('NumberInput', function () {
         downArrow.simulate('click');
         expect(onClick).toBeCalled();
         expect(onChange).toBeCalled();
-        expect(onClick).toHaveBeenCalledWith(expect.anything(), 'down');
+        expect(onClick).toHaveBeenCalledWith(expect.anything(), 'down', 0);
       });
       it('should invoke onChange when numberInput is changed', function () {
         input.simulate('change');
         expect(onChange).toBeCalled();
-        expect(onChange).toHaveBeenCalledWith(expect.anything());
+        expect(onChange).toHaveBeenCalledWith(expect.anything(), expect.anything());
       });
     });
   });
 });
 describe('NumberInputSkeleton', function () {
   describe('Renders as expected', function () {
-    var wrapper = shallow(React.createElement(NumberInputSkeleton, null));
+    var wrapper = shallow( /*#__PURE__*/React.createElement(NumberInputSkeleton, null));
     var container = wrapper.find(".".concat(prefix, "--number"));
     var label = wrapper.find(".".concat(prefix, "--label"));
     it('has the expected classes', function () {
