@@ -1,6 +1,6 @@
-var _triggerButtonPositio, _triggerButtonPositio2;
+function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }
 
-function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }
+var _triggerButtonPositio, _triggerButtonPositio2;
 
 function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
 
@@ -14,16 +14,20 @@ function _defineProperties(target, props) { for (var i = 0; i < props.length; i+
 
 function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }
 
-function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }
-
-function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
-
-function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
-
 function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }
 
 function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
 
+function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
+
+function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }
+
+function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
+
+function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
+
+function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
+
 function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
 
 /**
@@ -39,7 +43,6 @@ import classNames from 'classnames';
 import { settings } from 'carbon-components';
 import ClickListener from '../../internal/ClickListener';
 import FloatingMenu, { DIRECTION_TOP, DIRECTION_BOTTOM } from '../../internal/FloatingMenu';
-import OptimizedResize from '../../internal/OptimizedResize';
 import { OverflowMenuVertical16 } from '@carbon/icons-react';
 import { keys, matches as keyCodeMatches } from '../../internal/keyboard';
 import mergeRefs from '../../tools/mergeRefs';
@@ -117,14 +120,12 @@ export var getMenuOffset = function getMenuOffset(menuBody, direction, trigger,
   }
 };
 
-var OverflowMenu =
-/*#__PURE__*/
-function (_Component) {
+var OverflowMenu = /*#__PURE__*/function (_Component) {
   _inherits(OverflowMenu, _Component);
 
-  function OverflowMenu() {
-    var _getPrototypeOf2;
+  var _super = _createSuper(OverflowMenu);
 
+  function OverflowMenu() {
     var _this;
 
     _classCallCheck(this, OverflowMenu);
@@ -133,7 +134,7 @@ function (_Component) {
       args[_key2] = arguments[_key2];
     }
 
-    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(OverflowMenu)).call.apply(_getPrototypeOf2, [this].concat(args)));
+    _this = _super.call.apply(_super, [this].concat(args));
 
     _defineProperty(_assertThisInitialized(_this), "state", {});
 
@@ -141,31 +142,7 @@ function (_Component) {
 
     _defineProperty(_assertThisInitialized(_this), "_hBlurTimeout", void 0);
 
-    _defineProperty(_assertThisInitialized(_this), "getPrimaryFocusableElement", function () {
-      if (_this.menuEl) {
-        var primaryFocusPropEl = _this.menuEl.querySelector('[data-floating-menu-primary-focus]');
-
-        if (primaryFocusPropEl) {
-          return primaryFocusPropEl;
-        }
-      }
-
-      var firstItem = _this.overflowMenuItem0;
-
-      if (firstItem && firstItem.overflowMenuItem && firstItem.overflowMenuItem.current) {
-        return firstItem.overflowMenuItem.current;
-      }
-    });
-
-    _defineProperty(_assertThisInitialized(_this), "getMenuPosition", function () {
-      if (_this.menuEl) {
-        var menuPosition = _this.menuEl.getBoundingClientRect();
-
-        _this.setState({
-          menuPosition: menuPosition
-        });
-      }
-    });
+    _defineProperty(_assertThisInitialized(_this), "_triggerRef", /*#__PURE__*/React.createRef());
 
     _defineProperty(_assertThisInitialized(_this), "handleClick", function (evt) {
       if (!_this._menuBody || !_this._menuBody.contains(evt.target)) {
@@ -194,7 +171,13 @@ function (_Component) {
 
 
       if (keyCodeMatches(evt, [keys.Escape])) {
-        _this.closeMenu(); // Stop the esc keypress from bubbling out and closing something it shouldn't
+        var wasOpen = _this.state.open;
+
+        _this.closeMenu(function () {
+          if (wasOpen) {
+            _this.focusMenuEl();
+          }
+        }); // Stop the esc keypress from bubbling out and closing something it shouldn't
 
 
         evt.stopPropagation();
@@ -207,50 +190,58 @@ function (_Component) {
       }
     });
 
-    _defineProperty(_assertThisInitialized(_this), "closeMenu", function () {
-      var wasOpen = _this.state.open;
-
+    _defineProperty(_assertThisInitialized(_this), "closeMenu", function (onCloseMenu) {
       _this.setState({
         open: false
       }, function () {
-        if (wasOpen) {
-          _this.focusMenuEl();
+        // Optional callback to be executed after the state as been set to close
+        if (onCloseMenu) {
+          onCloseMenu();
         }
 
         _this.props.onClose();
       });
     });
 
-    _defineProperty(_assertThisInitialized(_this), "bindMenuEl", function (menuEl) {
-      _this.menuEl = menuEl;
-    });
-
     _defineProperty(_assertThisInitialized(_this), "focusMenuEl", function () {
-      if (_this.menuEl) {
-        _this.menuEl.focus();
+      var triggerEl = _this._triggerRef.current;
+
+      if (triggerEl) {
+        triggerEl.focus();
       }
     });
 
-    _defineProperty(_assertThisInitialized(_this), "handleOverflowMenuItemFocus", function (index) {
-      var i = function () {
-        switch (index) {
-          case -1:
-            return React.Children.count(_this.props.children) - 1;
+    _defineProperty(_assertThisInitialized(_this), "handleOverflowMenuItemFocus", function (_ref) {
+      var _overflowMenuItem$cur;
 
-          case React.Children.count(_this.props.children):
+      var currentIndex = _ref.currentIndex,
+          direction = _ref.direction;
+      var enabledIndices = React.Children.toArray(_this.props.children).reduce(function (acc, curr, i) {
+        if (!curr.props.disabled) {
+          acc.push(i);
+        }
+
+        return acc;
+      }, []);
+
+      var nextValidIndex = function () {
+        var nextIndex = enabledIndices.indexOf(currentIndex) + direction;
+
+        switch (enabledIndices.indexOf(currentIndex) + direction) {
+          case -1:
+            return enabledIndices.length - 1;
+
+          case enabledIndices.length:
             return 0;
 
           default:
-            return index;
+            return nextIndex;
         }
       }();
 
-      var _ref = _this["overflowMenuItem".concat(i)] || React.Children.toArray(_this.props.children)[i],
-          overflowMenuItem = _ref.overflowMenuItem;
+      var overflowMenuItem = _this["overflowMenuItem".concat(enabledIndices[nextValidIndex])].overflowMenuItem;
 
-      if (overflowMenuItem && overflowMenuItem.current) {
-        overflowMenuItem.current.focus();
-      }
+      overflowMenuItem === null || overflowMenuItem === void 0 ? void 0 : (_overflowMenuItem$cur = overflowMenuItem.current) === null || _overflowMenuItem$cur === void 0 ? void 0 : _overflowMenuItem$cur.focus();
     });
 
     _defineProperty(_assertThisInitialized(_this), "_bindMenuBody", function (menuBody) {
@@ -266,15 +257,16 @@ function (_Component) {
     _defineProperty(_assertThisInitialized(_this), "_handlePlace", function (menuBody) {
       if (menuBody) {
         _this._menuBody = menuBody;
-        var primaryFocus = menuBody.querySelector('[data-floating-menu-primary-focus]') || menuBody;
-        primaryFocus.focus();
-        var hasFocusin = 'onfocusin' in window;
+        var hasFocusin = ('onfocusin' in window);
         var focusinEventName = hasFocusin ? 'focusin' : 'focus';
         _this._hFocusIn = on(menuBody.ownerDocument, focusinEventName, function (event) {
-          var target = event.target;
+          var target = ClickListener.getEventTarget(event);
+          var triggerEl = _this._triggerRef.current;
 
-          if (!menuBody.contains(target) && _this.menuEl && !target.matches(".".concat(prefix, "--overflow-menu,.").concat(prefix, "--overflow-menu-options"))) {
-            _this.closeMenu();
+          if (typeof target.matches === 'function') {
+            if (!menuBody.contains(target) && triggerEl && !target.matches(".".concat(prefix, "--overflow-menu,.").concat(prefix, "--overflow-menu-options"))) {
+              _this.closeMenu();
+            }
           }
         }, !hasFocusin);
 
@@ -283,44 +275,19 @@ function (_Component) {
     });
 
     _defineProperty(_assertThisInitialized(_this), "_getTarget", function () {
-      return _this.menuEl && _this.menuEl.closest('[data-floating-menu-container]') || document.body;
+      var triggerEl = _this._triggerRef.current;
+      return triggerEl && triggerEl.closest('[data-floating-menu-container]') || document.body;
     });
 
     return _this;
   }
 
   _createClass(OverflowMenu, [{
-    key: "shouldComponentUpdate",
-    value: function shouldComponentUpdate(nextProps, nextState) {
-      var _this2 = this;
-
-      if (nextState.open && !this.state.open) {
-        requestAnimationFrame(function () {
-          _this2.getMenuPosition();
-        });
-        return false; // Let `.getMenuPosition()` cause render
-      }
-
-      return true;
-    }
-  }, {
-    key: "componentDidMount",
-    value: function componentDidMount() {
-      var _this3 = this;
-
-      requestAnimationFrame(function () {
-        _this3.getMenuPosition();
-      });
-      this.hResize = OptimizedResize.add(function () {
-        _this3.getMenuPosition();
-      });
-    }
-  }, {
     key: "componentDidUpdate",
-    value: function componentDidUpdate() {
+    value: function componentDidUpdate(_, prevState) {
       var onClose = this.props.onClose;
 
-      if (!this.state.open) {
+      if (!this.state.open && prevState.open) {
         onClose();
       }
     }
@@ -331,19 +298,16 @@ function (_Component) {
         clearTimeout(this._hBlurTimeout);
         this._hBlurTimeout = undefined;
       }
-
-      this.hResize.release();
     }
   }, {
     key: "render",
     value: function render() {
       var _classNames,
           _classNames2,
-          _this4 = this;
+          _this2 = this;
 
       var _this$props = this.props,
           id = _this$props.id,
-          tabIndex = _this$props.tabIndex,
           ariaLabel = _this$props.ariaLabel,
           children = _this$props.children,
           iconDescription = _this$props.iconDescription,
@@ -354,55 +318,60 @@ function (_Component) {
           iconClass = _this$props.iconClass,
           onClick = _this$props.onClick,
           onOpen = _this$props.onOpen,
+          _this$props$selectorP = _this$props.selectorPrimaryFocus,
+          selectorPrimaryFocus = _this$props$selectorP === void 0 ? '[data-floating-menu-primary-focus]' : _this$props$selectorP,
           IconElement = _this$props.renderIcon,
           ref = _this$props.innerRef,
           menuOptionsClass = _this$props.menuOptionsClass,
           light = _this$props.light,
-          other = _objectWithoutProperties(_this$props, ["id", "tabIndex", "ariaLabel", "children", "iconDescription", "direction", "flipped", "menuOffset", "menuOffsetFlip", "iconClass", "onClick", "onOpen", "renderIcon", "innerRef", "menuOptionsClass", "light"]);
+          size = _this$props.size,
+          other = _objectWithoutProperties(_this$props, ["id", "ariaLabel", "children", "iconDescription", "direction", "flipped", "menuOffset", "menuOffsetFlip", "iconClass", "onClick", "onOpen", "selectorPrimaryFocus", "renderIcon", "innerRef", "menuOptionsClass", "light", "size"]);
 
       var open = this.state.open;
-      var overflowMenuClasses = classNames(this.props.className, "".concat(prefix, "--overflow-menu"), (_classNames = {}, _defineProperty(_classNames, "".concat(prefix, "--overflow-menu--open"), open), _defineProperty(_classNames, "".concat(prefix, "--overflow-menu--light"), light), _classNames));
-      var overflowMenuOptionsClasses = classNames(menuOptionsClass, "".concat(prefix, "--overflow-menu-options"), (_classNames2 = {}, _defineProperty(_classNames2, "".concat(prefix, "--overflow-menu--flip"), this.props.flipped), _defineProperty(_classNames2, "".concat(prefix, "--overflow-menu-options--open"), open), _defineProperty(_classNames2, "".concat(prefix, "--overflow-menu-options--light"), light), _classNames2));
+      var overflowMenuClasses = classNames(this.props.className, "".concat(prefix, "--overflow-menu"), (_classNames = {}, _defineProperty(_classNames, "".concat(prefix, "--overflow-menu--open"), open), _defineProperty(_classNames, "".concat(prefix, "--overflow-menu--light"), light), _defineProperty(_classNames, "".concat(prefix, "--overflow-menu--").concat(size), size), _classNames));
+      var overflowMenuOptionsClasses = classNames(menuOptionsClass, "".concat(prefix, "--overflow-menu-options"), (_classNames2 = {}, _defineProperty(_classNames2, "".concat(prefix, "--overflow-menu--flip"), this.props.flipped), _defineProperty(_classNames2, "".concat(prefix, "--overflow-menu-options--open"), open), _defineProperty(_classNames2, "".concat(prefix, "--overflow-menu-options--light"), light), _defineProperty(_classNames2, "".concat(prefix, "--overflow-menu-options--").concat(size), size), _classNames2));
       var overflowMenuIconClasses = classNames("".concat(prefix, "--overflow-menu__icon"), iconClass);
       var childrenWithProps = React.Children.toArray(children).map(function (child, index) {
-        return React.cloneElement(child, {
-          closeMenu: _this4.closeMenu,
-          handleOverflowMenuItemFocus: _this4.handleOverflowMenuItemFocus,
+        var _child$props;
+
+        return /*#__PURE__*/React.cloneElement(child, {
+          closeMenu: (child === null || child === void 0 ? void 0 : (_child$props = child.props) === null || _child$props === void 0 ? void 0 : _child$props.closeMenu) || _this2.closeMenu,
+          handleOverflowMenuItemFocus: _this2.handleOverflowMenuItemFocus,
           ref: function ref(e) {
-            _this4["overflowMenuItem".concat(index)] = e;
+            _this2["overflowMenuItem".concat(index)] = e;
           },
           index: index
         });
       });
-      var menuBody = React.createElement("ul", {
+      var menuBody = /*#__PURE__*/React.createElement("ul", {
         className: overflowMenuOptionsClasses,
         tabIndex: "-1",
         role: "menu",
         "aria-label": ariaLabel
       }, childrenWithProps);
-      var wrappedMenuBody = React.createElement(FloatingMenu, {
-        menuPosition: this.state.menuPosition,
+      var wrappedMenuBody = /*#__PURE__*/React.createElement(FloatingMenu, {
+        focusTrap: true,
+        triggerRef: this._triggerRef,
         menuDirection: direction,
         menuOffset: flipped ? menuOffsetFlip : menuOffset,
         menuRef: this._bindMenuBody,
-        menuEl: this.menuEl,
         flipped: this.props.flipped,
         target: this._getTarget,
-        onPlace: this._handlePlace
-      }, React.cloneElement(menuBody, {
+        onPlace: this._handlePlace,
+        selectorPrimaryFocus: this.props.selectorPrimaryFocus
+      }, /*#__PURE__*/React.cloneElement(menuBody, {
         'data-floating-menu-direction': direction
       }));
       var iconProps = {
         onClick: this.handleClick,
         onKeyDown: this.handleKeyDown,
         className: overflowMenuIconClasses,
-        'aria-label': iconDescription,
-        focusable: 'false' // Prevent `<svg>` in trigger icon from getting focus for IE11
-
+        'aria-label': iconDescription
       };
-      return React.createElement(ClickListener, {
+      return /*#__PURE__*/React.createElement(ClickListener, {
         onClickOutside: this.handleClickOutside
-      }, React.createElement("button", _extends({}, other, {
+      }, /*#__PURE__*/React.createElement("button", _extends({}, other, {
+        type: "button",
         "aria-haspopup": true,
         "aria-expanded": this.state.open,
         className: overflowMenuClasses,
@@ -410,9 +379,8 @@ function (_Component) {
         onClick: this.handleClick,
         "aria-label": ariaLabel,
         id: id,
-        tabIndex: tabIndex,
-        ref: mergeRefs(ref, this.bindMenuEl)
-      }), React.createElement(IconElement, iconProps, iconDescription && React.createElement("title", null, iconDescription)), open && wrappedMenuBody));
+        ref: mergeRefs(this._triggerRef, ref)
+      }), /*#__PURE__*/React.createElement(IconElement, iconProps, iconDescription && /*#__PURE__*/React.createElement("title", null, iconDescription)), open && wrappedMenuBody));
     }
   }], [{
     key: "getDerivedStateFromProps",
@@ -431,19 +399,9 @@ function (_Component) {
 
 _defineProperty(OverflowMenu, "propTypes", {
   /**
-   * `true` if the menu should be open.
+   * The ARIA label.
    */
-  open: PropTypes.bool,
-
-  /**
-   * The menu direction.
-   */
-  direction: PropTypes.oneOf([DIRECTION_TOP, DIRECTION_BOTTOM]),
-
-  /**
-   * `true` if the menu alignment should be flipped.
-   */
-  flipped: PropTypes.bool,
+  ariaLabel: PropTypes.string,
 
   /**
    * The child nodes.
@@ -456,9 +414,24 @@ _defineProperty(OverflowMenu, "propTypes", {
   className: PropTypes.string,
 
   /**
-   * The `tabindex` attribute.
+   * The menu direction.
    */
-  tabIndex: PropTypes.number,
+  direction: PropTypes.oneOf([DIRECTION_TOP, DIRECTION_BOTTOM]),
+
+  /**
+   * `true` if the menu alignment should be flipped.
+   */
+  flipped: PropTypes.bool,
+
+  /**
+   * The CSS class for the icon.
+   */
+  iconClass: PropTypes.string,
+
+  /**
+   * The icon description.
+   */
+  iconDescription: PropTypes.string.isRequired,
 
   /**
    * The element ID.
@@ -466,29 +439,10 @@ _defineProperty(OverflowMenu, "propTypes", {
   id: PropTypes.string,
 
   /**
-   * The ARIA label.
+   * `true` to use the light version. For use on $ui-01 backgrounds only.
+   * Don't use this to make OverflowMenu background color same as container background color.
    */
-  ariaLabel: PropTypes.string,
-
-  /**
-   * The event handler for the `click` event.
-   */
-  onClick: PropTypes.func,
-
-  /**
-   * The event handler for the `focus` event.
-   */
-  onFocus: PropTypes.func,
-
-  /**
-   * The event handler for the `keydown` event.
-   */
-  onKeyDown: PropTypes.func,
-
-  /**
-   * The icon description.
-   */
-  iconDescription: PropTypes.string.isRequired,
+  light: PropTypes.bool,
 
   /**
    * The adjustment in position applied to the floating menu.
@@ -507,14 +461,14 @@ _defineProperty(OverflowMenu, "propTypes", {
   }), PropTypes.func]),
 
   /**
-   * The CSS class for the icon.
+   * The class to apply to the menu options
    */
-  iconClass: PropTypes.string,
+  menuOptionsClass: PropTypes.string,
 
   /**
-   * Function called to override icon rendering.
+   * The event handler for the `click` event.
    */
-  renderIcon: PropTypes.oneOfType([PropTypes.func, PropTypes.object]),
+  onClick: PropTypes.func,
 
   /**
    * Function called when menu is closed
@@ -522,24 +476,45 @@ _defineProperty(OverflowMenu, "propTypes", {
   onClose: PropTypes.func,
 
   /**
-   * The class to apply to the menu options
+   * The event handler for the `focus` event.
    */
-  menuOptionsClass: PropTypes.string,
+  onFocus: PropTypes.func,
 
   /**
-   * Function called when menu is closed
+   * The event handler for the `keydown` event.
+   */
+  onKeyDown: PropTypes.func,
+
+  /**
+   * Function called when menu is opened
    */
   onOpen: PropTypes.func,
 
   /**
-   * `true` to use the light version. For use on $ui-01 backgrounds only.
-   * Don't use this to make OverflowMenu background color same as container background color.
+   * `true` if the menu should be open.
    */
-  light: PropTypes.bool
+  open: PropTypes.bool,
+
+  /**
+   * Function called to override icon rendering.
+   */
+  renderIcon: PropTypes.oneOfType([PropTypes.func, PropTypes.object]),
+
+  /**
+   * Specify a CSS selector that matches the DOM element that should
+   * be focused when the OverflowMenu opens
+   */
+  selectorPrimaryFocus: PropTypes.string,
+
+  /**
+   * Specify the size of the OverflowMenu. Currently supports either `sm`, 'md' (default) or 'lg` as an option.
+   * TODO V11: remove `xl` (replaced with lg)
+   */
+  size: PropTypes.oneOf(['sm', 'md', 'lg', 'xl'])
 });
 
 _defineProperty(OverflowMenu, "defaultProps", {
-  ariaLabel: 'Menu',
+  ariaLabel: 'open and close list of options',
   iconDescription: 'open and close list of options',
   open: false,
   direction: DIRECTION_BOTTOM,
@@ -549,19 +524,20 @@ _defineProperty(OverflowMenu, "defaultProps", {
   onKeyDown: function onKeyDown() {},
   onClose: function onClose() {},
   onOpen: function onOpen() {},
-  tabIndex: 0,
   menuOffset: getMenuOffset,
   menuOffsetFlip: getMenuOffset,
-  light: false
+  light: false,
+  selectorPrimaryFocus: '[data-overflow-menu-primary-focus]'
 });
 
+export { OverflowMenu };
 export default (function () {
   var forwardRef = function forwardRef(props, ref) {
-    return React.createElement(OverflowMenu, _extends({}, props, {
+    return /*#__PURE__*/React.createElement(OverflowMenu, _extends({}, props, {
       innerRef: ref
     }));
   };
 
   forwardRef.displayName = 'OverflowMenu';
-  return React.forwardRef(forwardRef);
+  return /*#__PURE__*/React.forwardRef(forwardRef);
 })();
\ No newline at end of file
