@@ -10,7 +10,7 @@ import { shallow } from 'enzyme';
 import { settings } from 'carbon-components';
 var prefix = settings.prefix;
 describe('SkeletonPlaceholder', function () {
-  var wrapper = shallow(React.createElement(SkeletonPlaceholder, null));
+  var wrapper = shallow( /*#__PURE__*/React.createElement(SkeletonPlaceholder, null));
   it('Has the expected classes', function () {
     expect(wrapper.hasClass("".concat(prefix, "--skeleton__placeholder"))).toEqual(true);
   });
