@@ -1,4 +1,4 @@
-function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }
+function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }
 
 function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
 
@@ -12,16 +12,20 @@ function _defineProperties(target, props) { for (var i = 0; i < props.length; i+
 
 function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }
 
-function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }
-
-function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
-
-function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
-
 function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }
 
 function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
 
+function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
+
+function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }
+
+function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
+
+function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
+
+function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
+
 function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
 
 /**
@@ -61,14 +65,12 @@ var DRAG_EVENT_TYPES = new Set(['mousemove', 'touchmove']);
 
 var DRAG_STOP_EVENT_TYPES = new Set(['mouseup', 'touchend', 'touchcancel']);
 
-var Slider =
-/*#__PURE__*/
-function (_PureComponent) {
+var Slider = /*#__PURE__*/function (_PureComponent) {
   _inherits(Slider, _PureComponent);
 
-  function Slider() {
-    var _getPrototypeOf2;
+  var _super = _createSuper(Slider);
 
+  function Slider() {
     var _this;
 
     _classCallCheck(this, Slider);
@@ -77,7 +79,7 @@ function (_PureComponent) {
       args[_key] = arguments[_key];
     }
 
-    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Slider)).call.apply(_getPrototypeOf2, [this].concat(args)));
+    _this = _super.call.apply(_super, [this].concat(args));
 
     _defineProperty(_assertThisInitialized(_this), "state", {
       value: _this.props.value,
@@ -182,8 +184,12 @@ function (_PureComponent) {
         delta *= stepMultiplier;
       }
 
+      Math.floor(_this.state.value / _this.props.step) * _this.props.step;
+
       var _this$calcValue2 = _this.calcValue({
-        value: _this.state.value + delta
+        // Ensures custom value from `<input>` won't cause skipping next stepping point with right arrow key,
+        // e.g. Typing 51 in `<input>`, moving focus onto the thumb and the hitting right arrow key should yield 52 instead of 54
+        value: (delta > 0 ? Math.floor(_this.state.value / _this.props.step) * _this.props.step : _this.state.value) + delta
       }),
           value = _this$calcValue2.value,
           left = _this$calcValue2.left;
@@ -205,17 +211,22 @@ function (_PureComponent) {
         return;
       }
 
-      var targetValue = Number.parseFloat(evt.target.value); // Avoid calling calcValue for invaid numbers, but still update the state
+      var targetValue = Number.parseFloat(evt.target.value); // Avoid calling calcValue for invalid numbers, but still update the state
 
       if (isNaN(targetValue)) {
         _this.setState({
           value: evt.target.value
         });
       } else {
-        targetValue = _this.clamp(targetValue, _this.props.min, _this.props.max); // Recalculate the state's value and update the Slider
+        // Recalculate the state's value and update the Slider
+        // if it is a valid number
+        if (evt.target.checkValidity() === false) {
+          return;
+        }
 
         var _this$calcValue3 = _this.calcValue({
-          value: targetValue
+          value: targetValue,
+          useRawValue: true
         }),
             value = _this$calcValue3.value,
             left = _this$calcValue3.left;
@@ -232,7 +243,9 @@ function (_PureComponent) {
       var _ref$clientX = _ref.clientX,
           clientX = _ref$clientX === void 0 ? null : _ref$clientX,
           _ref$value = _ref.value,
-          value = _ref$value === void 0 ? null : _ref$value;
+          value = _ref$value === void 0 ? null : _ref$value,
+          _ref$useRawValue = _ref.useRawValue,
+          useRawValue = _ref$useRawValue === void 0 ? false : _ref$useRawValue;
       var range = _this.props.max - _this.props.min;
 
       var boundingRect = _this.element.getBoundingClientRect();
@@ -254,9 +267,18 @@ function (_PureComponent) {
       } else {
         if (value == null) {
           value = _this.state.value;
-        }
+        } // prevent NaN calculation if the range is 0
 
-        leftPercent = value / (range - _this.props.min);
+
+        leftPercent = range === 0 ? 0 : (value - _this.props.min) / range;
+      }
+
+      if (useRawValue) {
+        // Adjusts only for min/max of thumb position
+        return {
+          value: value,
+          left: Math.min(1, Math.max(0, leftPercent)) * 100
+        };
       }
 
       var steppedValue = Math.round(leftPercent * totalSteps) * _this.props.step;
@@ -275,35 +297,40 @@ function (_PureComponent) {
 
   _createClass(Slider, [{
     key: "componentDidMount",
-
+    value:
     /**
      * Sets up initial slider position and value in response to component mount.
      */
-    value: function componentDidMount() {
-      var _this$calcValue4 = this.calcValue({}),
-          value = _this$calcValue4.value,
-          left = _this$calcValue4.left;
+    function componentDidMount() {
+      if (this.element) {
+        var _this$calcValue4 = this.calcValue({
+          useRawValue: true
+        }),
+            value = _this$calcValue4.value,
+            left = _this$calcValue4.left;
 
-      this.setState({
-        value: value,
-        left: left
-      });
+        this.setState({
+          value: value,
+          left: left
+        });
+      }
     }
     /**
      * Handles firing of `onChange` and `onRelease` callbacks to parent in
      * response to state changes.
      *
-     * @param {*} _ Unused (prevProps)
+     * @param {*} prevProps prevProps
      * @param {*} prevState The previous Slider state, used to see if callbacks
      * should be called.
      */
 
   }, {
     key: "componentDidUpdate",
-    value: function componentDidUpdate(_, prevState) {
+    value: function componentDidUpdate(prevProps, prevState) {
       // Fire onChange event handler if present, if there's a usable value, and
       // if the value is different from the last one
       if (this.state.value !== '' && prevState.value !== this.state.value && typeof this.props.onChange === 'function') {
+        // TODO: pass event object as first param (breaking change/feat for v11)
         this.props.onChange({
           value: this.state.value
         });
@@ -311,6 +338,7 @@ function (_PureComponent) {
 
 
       if (this.state.needsOnRelease && typeof this.props.onRelease === 'function') {
+        // TODO: pass event object as first param (breaking change/feat for v11)
         this.props.onRelease({
           value: this.state.value
         }); // Reset the flag
@@ -318,7 +346,18 @@ function (_PureComponent) {
         this.setState({
           needsOnRelease: false
         });
+      } // If value from props does not change, do nothing here.
+      // Otherwise, do prop -> state sync without "value capping".
+
+
+      if (prevProps.value === this.props.value && prevProps.max === this.props.max && prevProps.min === this.props.min) {
+        return;
       }
+
+      this.setState(this.calcValue({
+        value: this.props.value,
+        useRawValue: true
+      }));
     }
     /**
      * Synonymous to ECMA2017+ `Math.clamp`.
@@ -370,12 +409,14 @@ function (_PureComponent) {
           disabled = _this$props.disabled,
           name = _this$props.name,
           light = _this$props.light,
-          other = _objectWithoutProperties(_this$props, ["ariaLabelInput", "className", "hideTextInput", "id", "min", "minLabel", "max", "maxLabel", "formatLabel", "labelText", "step", "stepMuliplier", "stepMultiplier", "inputType", "required", "disabled", "name", "light"]);
+          invalid = _this$props.invalid,
+          other = _objectWithoutProperties(_this$props, ["ariaLabelInput", "className", "hideTextInput", "id", "min", "minLabel", "max", "maxLabel", "formatLabel", "labelText", "step", "stepMuliplier", "stepMultiplier", "inputType", "required", "disabled", "name", "light", "invalid"]);
 
       delete other.onRelease;
       var _this$state = this.state,
           value = _this$state.value,
           left = _this$state.left;
+      var labelId = "".concat(id, "-label");
       var labelClasses = classNames("".concat(prefix, "--label"), _defineProperty({}, "".concat(prefix, "--label--disabled"), disabled));
       var sliderClasses = classNames("".concat(prefix, "--slider"), _defineProperty({}, "".concat(prefix, "--slider--disabled"), disabled), className);
       var inputClasses = classNames("".concat(prefix, "--text-input"), "".concat(prefix, "--slider-text-input"), (_classNames3 = {}, _defineProperty(_classNames3, "".concat(prefix, "--text-input--light"), light), _defineProperty(_classNames3, "".concat(prefix, "--text-input--invalid"), this.props.invalid), _classNames3));
@@ -388,16 +429,17 @@ function (_PureComponent) {
       var hiddenInputStyle = {
         display: 'none'
       };
-      return React.createElement("div", {
+      return /*#__PURE__*/React.createElement("div", {
         className: "".concat(prefix, "--form-item")
-      }, React.createElement("label", {
+      }, /*#__PURE__*/React.createElement("label", {
         htmlFor: id,
-        className: labelClasses
-      }, labelText), React.createElement("div", {
+        className: labelClasses,
+        id: labelId
+      }, labelText), /*#__PURE__*/React.createElement("div", {
         className: "".concat(prefix, "--slider-container")
-      }, React.createElement("span", {
+      }, /*#__PURE__*/React.createElement("span", {
         className: "".concat(prefix, "--slider__range-label")
-      }, formatLabel(min, minLabel)), React.createElement("div", _extends({
+      }, formatLabel(min, minLabel)), /*#__PURE__*/React.createElement("div", _extends({
         className: sliderClasses,
         ref: function ref(node) {
           _this2.element = node;
@@ -406,27 +448,29 @@ function (_PureComponent) {
         onTouchStart: this.onDragStart,
         onKeyDown: this.onKeyDown,
         role: "presentation",
-        tabIndex: -1
-      }, other), React.createElement("div", {
+        tabIndex: -1,
+        "data-invalid": invalid || null
+      }, other), /*#__PURE__*/React.createElement("div", {
         className: "".concat(prefix, "--slider__thumb"),
         role: "slider",
         id: id,
         tabIndex: 0,
+        "aria-labelledby": labelId,
         "aria-valuemax": max,
         "aria-valuemin": min,
         "aria-valuenow": value,
         style: thumbStyle
-      }), React.createElement("div", {
+      }), /*#__PURE__*/React.createElement("div", {
         className: "".concat(prefix, "--slider__track"),
         ref: function ref(node) {
           _this2.track = node;
         }
-      }), React.createElement("div", {
+      }), /*#__PURE__*/React.createElement("div", {
         className: "".concat(prefix, "--slider__filled-track"),
         style: filledTrackStyle
-      })), React.createElement("span", {
+      })), /*#__PURE__*/React.createElement("span", {
         className: "".concat(prefix, "--slider__range-label")
-      }, formatLabel(max, maxLabel)), React.createElement("input", {
+      }, formatLabel(max, maxLabel)), /*#__PURE__*/React.createElement("input", {
         type: hideTextInput ? 'hidden' : inputType,
         style: hideTextInput ? hiddenInputStyle : null,
         id: "".concat(id, "-input-for-slider"),
@@ -439,7 +483,9 @@ function (_PureComponent) {
         min: min,
         max: max,
         step: step,
-        onChange: this.onChange
+        onChange: this.onChange,
+        "data-invalid": invalid || null,
+        "aria-invalid": invalid || null
       })));
     }
   }]);
@@ -448,11 +494,31 @@ function (_PureComponent) {
 }(PureComponent);
 
 _defineProperty(Slider, "propTypes", {
+  /**
+   * The `ariaLabel` for the `<input>`.
+   */
+  ariaLabelInput: PropTypes.string,
+
+  /**
+   * The child nodes.
+   */
+  children: PropTypes.node,
+
   /**
    * The CSS class name for the slider.
    */
   className: PropTypes.string,
 
+  /**
+   * `true` to disable this slider.
+   */
+  disabled: PropTypes.bool,
+
+  /**
+   * The callback to format the label associated with the minimum/maximum value.
+   */
+  formatLabel: PropTypes.func,
+
   /**
    * `true` to hide the number input box.
    */
@@ -464,29 +530,24 @@ _defineProperty(Slider, "propTypes", {
   id: PropTypes.string,
 
   /**
-   * The callback to get notified of change in value.
+   * The `type` attribute of the `<input>`.
    */
-  onChange: PropTypes.func,
+  inputType: PropTypes.string,
 
   /**
-   * The callback to get notified of value on handle release.
+   * `true` to specify if the control is invalid.
    */
-  onRelease: PropTypes.func,
+  invalid: PropTypes.bool,
 
   /**
-   * The value.
+   * The label for the slider.
    */
-  value: PropTypes.number.isRequired,
+  labelText: PropTypes.node,
 
   /**
-   * The minimum value.
+   * `true` to use the light version.
    */
-  min: PropTypes.number.isRequired,
-
-  /**
-   * The label associated with the minimum value.
-   */
-  minLabel: PropTypes.string,
+  light: PropTypes.bool,
 
   /**
    * The maximum value.
@@ -499,14 +560,34 @@ _defineProperty(Slider, "propTypes", {
   maxLabel: PropTypes.string,
 
   /**
-   * The callback to format the label associated with the minimum/maximum value.
+   * The minimum value.
    */
-  formatLabel: PropTypes.func,
+  min: PropTypes.number.isRequired,
 
   /**
-   * The label for the slider.
+   * The label associated with the minimum value.
    */
-  labelText: PropTypes.node,
+  minLabel: PropTypes.string,
+
+  /**
+   * The `name` attribute of the `<input>`.
+   */
+  name: PropTypes.string,
+
+  /**
+   * The callback to get notified of change in value.
+   */
+  onChange: PropTypes.func,
+
+  /**
+   * The callback to get notified of value on handle release.
+   */
+  onRelease: PropTypes.func,
+
+  /**
+   * `true` to specify if the control is required.
+   */
+  required: PropTypes.bool,
 
   /**
    * A value determining how much the value should increase/decrease by moving the thumb by mouse.
@@ -526,34 +607,9 @@ _defineProperty(Slider, "propTypes", {
   stepMultiplier: PropTypes.number,
 
   /**
-   * The child nodes.
+   * The value.
    */
-  children: PropTypes.node,
-
-  /**
-   * `true` to disable this slider.
-   */
-  disabled: PropTypes.bool,
-
-  /**
-   * The `name` attribute of the `<input>`.
-   */
-  name: PropTypes.string,
-
-  /**
-   * The `type` attribute of the `<input>`.
-   */
-  inputType: PropTypes.string,
-
-  /**
-   * The `ariaLabel` for the `<input>`.
-   */
-  ariaLabelInput: PropTypes.string,
-
-  /**
-   * `true` to use the light version.
-   */
-  light: PropTypes.bool
+  value: PropTypes.number.isRequired
 });
 
 _defineProperty(Slider, "defaultProps", {
