@@ -1,4 +1,4 @@
-function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }
+function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }
 
 function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
 
@@ -12,17 +12,21 @@ function _defineProperties(target, props) { for (var i = 0; i < props.length; i+
 
 function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }
 
-function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }
-
-function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
-
-function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
-
 function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }
 
 function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
 
-function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }
+function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
+
+function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }
+
+function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
+
+function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
+
+function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
+
+function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }
 
 function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
 
@@ -63,7 +67,7 @@ var getMenuOffset = function getMenuOffset(menuBody, menuDirection) {
   var arrowPositionProp = (_DIRECTION_LEFT$DIREC = {}, _defineProperty(_DIRECTION_LEFT$DIREC, DIRECTION_LEFT, 'right'), _defineProperty(_DIRECTION_LEFT$DIREC, DIRECTION_TOP, 'bottom'), _defineProperty(_DIRECTION_LEFT$DIREC, DIRECTION_RIGHT, 'left'), _defineProperty(_DIRECTION_LEFT$DIREC, DIRECTION_BOTTOM, 'top'), _DIRECTION_LEFT$DIREC)[menuDirection];
   var menuPositionAdjustmentProp = (_DIRECTION_LEFT$DIREC2 = {}, _defineProperty(_DIRECTION_LEFT$DIREC2, DIRECTION_LEFT, 'left'), _defineProperty(_DIRECTION_LEFT$DIREC2, DIRECTION_TOP, 'top'), _defineProperty(_DIRECTION_LEFT$DIREC2, DIRECTION_RIGHT, 'left'), _defineProperty(_DIRECTION_LEFT$DIREC2, DIRECTION_BOTTOM, 'top'), _DIRECTION_LEFT$DIREC2)[menuDirection];
   var values = [arrowPositionProp, 'border-bottom-width'].reduce(function (o, name) {
-    return _objectSpread({}, o, _defineProperty({}, name, Number((/^([\d-]+)px$/.exec(arrowStyle.getPropertyValue(name)) || [])[1])));
+    return _objectSpread(_objectSpread({}, o), {}, _defineProperty({}, name, Number((/^([\d-]+)px$/.exec(arrowStyle.getPropertyValue(name)) || [])[1])));
   }, {});
   values[arrowPositionProp] = values[arrowPositionProp] || -6; // IE, etc.
 
@@ -79,23 +83,41 @@ var getMenuOffset = function getMenuOffset(menuBody, menuDirection) {
   }
 };
 
-var Tooltip =
-/*#__PURE__*/
-function (_Component) {
+var Tooltip = /*#__PURE__*/function (_Component) {
   _inherits(Tooltip, _Component);
 
+  var _super = _createSuper(Tooltip);
+
   function Tooltip(props) {
     var _this;
 
     _classCallCheck(this, Tooltip);
 
-    _this = _possibleConstructorReturn(this, _getPrototypeOf(Tooltip).call(this, props));
+    _this = _super.call(this, props);
 
     _defineProperty(_assertThisInitialized(_this), "_tooltipEl", null);
 
+    _defineProperty(_assertThisInitialized(_this), "_triggerRef", /*#__PURE__*/React.createRef());
+
+    _defineProperty(_assertThisInitialized(_this), "_tooltipId", _this.props.id || _this.props.tooltipId || "__carbon-tooltip_".concat(Math.random().toString(36).substr(2)));
+
+    _defineProperty(_assertThisInitialized(_this), "_tooltipDismissed", false);
+
     _defineProperty(_assertThisInitialized(_this), "_handleUserInputOpenClose", function (event, _ref2) {
       var open = _ref2.open;
 
+      if (_this.isControlled) {
+        // Callback to the parent to let them decide what to do
+        _this.props.onChange(event, {
+          open: open
+        });
+
+        return;
+      } // capture tooltip body element before it is removed from the DOM
+
+
+      var tooltipBody = _this._tooltipEl;
+
       _this.setState({
         open: open
       }, function () {
@@ -104,31 +126,41 @@ function (_Component) {
             open: open
           });
         }
+
+        if (!open && tooltipBody && tooltipBody.id === _this._tooltipId) {
+          _this._tooltipDismissed = true;
+          var currentActiveNode = event === null || event === void 0 ? void 0 : event.relatedTarget;
+
+          if (!currentActiveNode && document.activeElement === document.body && (event === null || event === void 0 ? void 0 : event.type) !== 'click') {
+            var _this$_triggerRef;
+
+            (_this$_triggerRef = _this._triggerRef) === null || _this$_triggerRef === void 0 ? void 0 : _this$_triggerRef.current.focus();
+          }
+        }
       });
     });
 
-    _defineProperty(_assertThisInitialized(_this), "getTriggerPosition", function () {
-      if (_this.triggerEl) {
-        var triggerPosition = _this.triggerEl.getBoundingClientRect();
-
-        _this.setState({
-          triggerPosition: triggerPosition
-        });
-      }
-    });
-
     _defineProperty(_assertThisInitialized(_this), "_handleFocus", function (state, evt) {
-      var relatedTarget = evt.relatedTarget;
+      var currentTarget = evt.currentTarget,
+          relatedTarget = evt.relatedTarget;
+
+      if (currentTarget !== relatedTarget) {
+        _this._tooltipDismissed = false;
+      }
 
       if (state === 'over') {
-        _this.getTriggerPosition();
+        if (!_this._tooltipDismissed) {
+          _this._handleUserInputOpenClose(evt, {
+            open: true
+          });
+        }
 
-        _this._handleUserInputOpenClose(evt, {
-          open: true
-        });
-      } else {
+        _this._tooltipDismissed = false;
+      } else if (state !== 'out') {
         // Note: SVGElement in IE11 does not have `.contains()`
-        var shouldPreventClose = relatedTarget && (_this.triggerEl && _this.triggerEl.contains && _this.triggerEl.contains(relatedTarget) || _this._tooltipEl && _this._tooltipEl.contains(relatedTarget));
+        var triggerEl = _this._triggerRef.current;
+
+        var shouldPreventClose = relatedTarget && (triggerEl && (triggerEl === null || triggerEl === void 0 ? void 0 : triggerEl.contains(relatedTarget)) || _this._tooltipEl && _this._tooltipEl.contains(relatedTarget));
 
         if (!shouldPreventClose) {
           _this._handleUserInputOpenClose(evt, {
@@ -141,7 +173,8 @@ function (_Component) {
     _defineProperty(_assertThisInitialized(_this), "_debouncedHandleFocus", null);
 
     _defineProperty(_assertThisInitialized(_this), "_getTarget", function () {
-      return _this.triggerEl && _this.triggerEl.closest('[data-floating-menu-container]') || document.body;
+      var triggerEl = _this._triggerRef.current;
+      return triggerEl && triggerEl.closest('[data-floating-menu-container]') || document.body;
     });
 
     _defineProperty(_assertThisInitialized(_this), "handleMouse", function (evt) {
@@ -152,22 +185,31 @@ function (_Component) {
         click: 'click'
       }[evt.type];
       var hadContextMenu = _this._hasContextMenu;
-      _this._hasContextMenu = evt.type === 'contextmenu';
+
+      if (evt.type === 'click' || evt.type === 'contextmenu') {
+        _this._hasContextMenu = evt.type === 'contextmenu';
+      }
+
+      if (_this._hasContextMenu) {
+        _this._handleUserInputOpenClose(evt, {
+          open: false
+        });
+
+        return;
+      }
 
       if (state === 'click') {
         evt.stopPropagation();
         evt.preventDefault();
         var shouldOpen = _this.isControlled ? !_this.props.open : !_this.state.open;
 
-        if (shouldOpen) {
-          _this.getTriggerPosition();
-        }
-
         _this._handleUserInputOpenClose(evt, {
           open: shouldOpen
         });
-      } else if (state && (state !== 'out' || !hadContextMenu) && _this._debouncedHandleFocus) {
-        _this._debouncedHandleFocus(state, evt);
+      } else if (state && (state !== 'out' || !hadContextMenu)) {
+        var _assertThisInitialize;
+
+        (_assertThisInitialize = _assertThisInitialized(_this)) === null || _assertThisInitialize === void 0 ? void 0 : _assertThisInitialize._debouncedHandleFocus(state, evt);
       }
     });
 
@@ -195,10 +237,6 @@ function (_Component) {
         event.preventDefault();
         var shouldOpen = _this.isControlled ? !_this.props.open : !_this.state.open;
 
-        if (shouldOpen) {
-          _this.getTriggerPosition();
-        }
-
         _this._handleUserInputOpenClose(event, {
           open: shouldOpen
         });
@@ -210,6 +248,7 @@ function (_Component) {
           open = _ref3.open;
 
       if (open && keyDownMatch(event, [keys.Escape])) {
+        event.stopPropagation();
         return _this._handleUserInputOpenClose(event, {
           open: false
         });
@@ -234,15 +273,10 @@ function (_Component) {
   _createClass(Tooltip, [{
     key: "componentDidMount",
     value: function componentDidMount() {
-      var _this2 = this;
-
       if (!this._debouncedHandleFocus) {
         this._debouncedHandleFocus = debounce(this._handleFocus, 200);
       }
 
-      requestAnimationFrame(function () {
-        _this2.getTriggerPosition();
-      });
       document.addEventListener('keydown', this.handleEscKeyPress, false);
     }
   }, {
@@ -259,18 +293,19 @@ function (_Component) {
   }, {
     key: "render",
     value: function render() {
-      var _this3 = this;
+      var _classNames,
+          _this2 = this;
 
       var _this$props = this.props,
           _this$props$triggerId = _this$props.triggerId,
           triggerId = _this$props$triggerId === void 0 ? this.triggerId = this.triggerId || "__carbon-tooltip-trigger_".concat(Math.random().toString(36).substr(2)) : _this$props$triggerId,
-          _this$props$tooltipId = _this$props.tooltipId,
-          tooltipId = _this$props$tooltipId === void 0 ? this.tooltipId = this.tooltipId || "__carbon-tooltip_".concat(Math.random().toString(36).substr(2)) : _this$props$tooltipId,
           tooltipBodyId = _this$props.tooltipBodyId,
           children = _this$props.children,
           className = _this$props.className,
           triggerClassName = _this$props.triggerClassName,
           direction = _this$props.direction,
+          align = _this$props.align,
+          focusTrap = _this$props.focusTrap,
           triggerText = _this$props.triggerText,
           showIcon = _this$props.showIcon,
           iconName = _this$props.iconName,
@@ -280,16 +315,16 @@ function (_Component) {
           _this$props$tabIndex = _this$props.tabIndex,
           tabIndex = _this$props$tabIndex === void 0 ? 0 : _this$props$tabIndex,
           ref = _this$props.innerRef,
-          other = _objectWithoutProperties(_this$props, ["triggerId", "tooltipId", "tooltipBodyId", "children", "className", "triggerClassName", "direction", "triggerText", "showIcon", "iconName", "iconDescription", "renderIcon", "menuOffset", "tabIndex", "innerRef"]);
+          selectorPrimaryFocus = _this$props.selectorPrimaryFocus,
+          tooltipId = _this$props.tooltipId,
+          other = _objectWithoutProperties(_this$props, ["triggerId", "tooltipBodyId", "children", "className", "triggerClassName", "direction", "align", "focusTrap", "triggerText", "showIcon", "iconName", "iconDescription", "renderIcon", "menuOffset", "tabIndex", "innerRef", "selectorPrimaryFocus", "tooltipId"]);
 
       var _ref4 = this.isControlled ? this.props : this.state,
           open = _ref4.open;
 
-      var tooltipClasses = classNames("".concat(prefix, "--tooltip"), _defineProperty({}, "".concat(prefix, "--tooltip--shown"), open), className);
+      var tooltipClasses = classNames("".concat(prefix, "--tooltip"), (_classNames = {}, _defineProperty(_classNames, "".concat(prefix, "--tooltip--shown"), open), _defineProperty(_classNames, "".concat(prefix, "--tooltip--").concat(direction), direction), _defineProperty(_classNames, "".concat(prefix, "--tooltip--align-").concat(align), align), _classNames), className);
       var triggerClasses = classNames("".concat(prefix, "--tooltip__label"), triggerClassName);
-      var refProp = mergeRefs(ref, function (node) {
-        _this3.triggerEl = node;
-      });
+      var refProp = mergeRefs(this._triggerRef, ref);
       var iconProperties = {
         name: iconName,
         role: null,
@@ -300,60 +335,62 @@ function (_Component) {
         role: 'button',
         tabIndex: tabIndex,
         onClick: this.handleMouse,
+        onContextMenu: this.handleMouse,
         onKeyDown: this.handleKeyPress,
         onMouseOver: this.handleMouse,
         onMouseOut: this.handleMouse,
         onFocus: this.handleMouse,
         onBlur: this.handleMouse,
-        'aria-controls': !open ? undefined : tooltipId,
+        'aria-controls': !open ? undefined : this._tooltipId,
         'aria-expanded': open,
-        'aria-describedby': open ? tooltipId : null
+        'aria-describedby': open ? this._tooltipId : null
       }, triggerText ? {
         'aria-labelledby': triggerId
       } : {
         'aria-label': iconDescription
       });
 
-      return React.createElement(React.Fragment, null, React.createElement(ClickListener, {
+      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(ClickListener, {
         onClickOutside: this.handleClickOutside
-      }, showIcon ? React.createElement("div", {
+      }, showIcon ? /*#__PURE__*/React.createElement("div", {
         id: triggerId,
         className: triggerClasses
-      }, triggerText, React.createElement("div", _extends({
+      }, triggerText, /*#__PURE__*/React.createElement("div", _extends({
         className: "".concat(prefix, "--tooltip__trigger")
-      }, properties), React.createElement(IconCustomElement, _extends({
-        ref: refProp
-      }, iconProperties)))) : React.createElement("div", _extends({
+      }, properties, {
+        ref: refProp,
+        "aria-describedby": tooltipBodyId
+      }), /*#__PURE__*/React.createElement(IconCustomElement, iconProperties))) : /*#__PURE__*/React.createElement("div", _extends({
         id: triggerId,
         className: triggerClasses,
         ref: refProp
-      }, properties), triggerText)), open && React.createElement(FloatingMenu, {
+      }, properties, {
+        "aria-describedby": tooltipBodyId
+      }), triggerText)), open && /*#__PURE__*/React.createElement(FloatingMenu, {
+        focusTrap: focusTrap,
+        selectorPrimaryFocus: this.props.selectorPrimaryFocus,
         target: this._getTarget,
-        menuPosition: this.state.triggerPosition,
+        triggerRef: this._triggerRef,
         menuDirection: direction,
         menuOffset: menuOffset,
         menuRef: function menuRef(node) {
-          _this3._tooltipEl = node;
+          _this2._tooltipEl = node;
         }
-      }, React.createElement("div", _extends({
-        id: tooltipId,
+      }, /*#__PURE__*/React.createElement("div", _extends({
         className: tooltipClasses
       }, other, {
+        id: this._tooltipId,
         "data-floating-menu-direction": direction,
         onMouseOver: this.handleMouse,
         onMouseOut: this.handleMouse,
         onFocus: this.handleMouse,
         onBlur: this.handleMouse,
-        onContextMenu: this.handleMouse,
-        role: "tooltip"
-      }), React.createElement("span", {
+        onContextMenu: this.handleMouse
+      }), /*#__PURE__*/React.createElement("span", {
         className: "".concat(prefix, "--tooltip__caret")
-      }), React.createElement("div", {
+      }), /*#__PURE__*/React.createElement("div", {
         className: "".concat(prefix, "--tooltip__content"),
-        tabindex: "-1",
-        role: "dialog",
-        "aria-describedby": tooltipBodyId,
-        "aria-labelledby": triggerId
+        role: "dialog"
       }, children))));
     }
   }], [{
@@ -377,29 +414,10 @@ function (_Component) {
 
 _defineProperty(Tooltip, "propTypes", _objectSpread({
   /**
-   * The ID of the trigger button.
+   * Specify the alignment (to the trigger button) of the tooltip.
+   * Can be one of: start, center, or end.
    */
-  triggerId: PropTypes.string,
-
-  /**
-   * The ID of the tooltip content.
-   */
-  tooltipId: PropTypes.string,
-
-  /**
-   * The ID of the tooltip body content.
-   */
-  tooltipBodyId: PropTypes.string,
-
-  /**
-   * Optional starting value for uncontrolled state
-   */
-  defaultOpen: PropTypes.bool,
-
-  /**
-   * Open/closed state.
-   */
-  open: PropTypes.bool,
+  align: PropTypes.oneOf(['start', 'center', 'end']),
 
   /**
    * Contents to put into the tooltip.
@@ -412,15 +430,25 @@ _defineProperty(Tooltip, "propTypes", _objectSpread({
   className: PropTypes.string,
 
   /**
-   * The CSS class names of the trigger UI.
+   * Optional starting value for uncontrolled state
    */
-  triggerClassName: PropTypes.string,
+  defaultOpen: PropTypes.bool,
 
   /**
    * Where to put the tooltip, relative to the trigger UI.
    */
   direction: PropTypes.oneOf(['bottom', 'top', 'left', 'right']),
 
+  /**
+   * Enable or disable focus trap behavior
+   */
+  focusTrap: PropTypes.bool,
+
+  /**
+   * The name of the default tooltip icon.
+   */
+  iconName: PropTypes.string,
+
   /**
    * The adjustment of the tooltip position.
    */
@@ -429,6 +457,19 @@ _defineProperty(Tooltip, "propTypes", _objectSpread({
     left: PropTypes.number
   }), PropTypes.func]),
 
+  /**
+   * * the signature of the event handler will be:
+   * * `onChange(event, { open })` where:
+   *   * `event` is the (React) raw event
+   *   * `open` is the new value
+   */
+  onChange: !useControlledStateWithValue ? PropTypes.func : requiredIfValueExists(PropTypes.func),
+
+  /**
+   * Open/closed state.
+   */
+  open: PropTypes.bool,
+
   /**
    * The callback function to optionally render the icon element.
    * It should be a component with React.forwardRef().
@@ -439,18 +480,47 @@ _defineProperty(Tooltip, "propTypes", _objectSpread({
     }
 
     var RefForwardingComponent = props[propName];
-    if (!isForwardRef(React.createElement(RefForwardingComponent, null))) return new Error("Invalid value of prop '".concat(propName, "' supplied to '").concat(componentName, "',\n                          it should be created/wrapped with React.forwardRef() to have a ref and access the proper\n                          DOM node of the element to calculate its position in the viewport."));
+
+    if (!isForwardRef( /*#__PURE__*/React.createElement(RefForwardingComponent, null))) {
+      return new Error("Invalid value of prop '".concat(propName, "' supplied to '").concat(componentName, "',\n                          it should be created/wrapped with React.forwardRef() to have a ref and access the proper\n                          DOM node of the element to calculate its position in the viewport."));
+    }
   },
 
+  /**
+   * Specify a CSS selector that matches the DOM element that should
+   * be focused when the Tooltip opens
+   */
+  selectorPrimaryFocus: PropTypes.string,
+
   /**
    * `true` to show the default tooltip icon.
    */
   showIcon: PropTypes.bool,
 
   /**
-   * The name of the default tooltip icon.
+   * Optional prop to specify the tabIndex of the Tooltip
    */
-  iconName: PropTypes.string
+  tabIndex: PropTypes.number,
+
+  /**
+   * The ID of the tooltip body content.
+   */
+  tooltipBodyId: PropTypes.string,
+
+  /**
+   * The ID of the tooltip content.
+   */
+  tooltipId: PropTypes.string,
+
+  /**
+   * The CSS class names of the trigger UI.
+   */
+  triggerClassName: PropTypes.string,
+
+  /**
+   * The ID of the trigger button.
+   */
+  triggerId: PropTypes.string
 }, isRequiredOneOf({
   /**
    * The content to put into the trigger UI, except the (default) tooltip icon.
@@ -461,36 +531,27 @@ _defineProperty(Tooltip, "propTypes", _objectSpread({
    * The description of the default tooltip icon, to be put in its SVG 'aria-label' and 'alt' .
    */
   iconDescription: PropTypes.string
-}), {
-  /**
-   * Optional prop to specify the tabIndex of the Tooltip
-   */
-  tabIndex: PropTypes.number,
-
-  /**
-   * * the signature of the event handler will be:
-   * * `onChange(event, { open })` where:
-   *   * `event` is the (React) raw event
-   *   * `open` is the new value
-   */
-  onChange: !useControlledStateWithValue ? PropTypes.func : requiredIfValueExists(PropTypes.func)
-}));
+})));
 
 _defineProperty(Tooltip, "defaultProps", {
+  align: 'center',
   direction: DIRECTION_BOTTOM,
+  focusTrap: true,
   renderIcon: Information,
   showIcon: true,
   triggerText: null,
-  menuOffset: getMenuOffset
+  menuOffset: getMenuOffset,
+  selectorPrimaryFocus: '[data-tooltip-primary-focus]'
 });
 
+export { Tooltip };
 export default (function () {
   var forwardRef = function forwardRef(props, ref) {
-    return React.createElement(Tooltip, _extends({}, props, {
+    return /*#__PURE__*/React.createElement(Tooltip, _extends({}, props, {
       innerRef: ref
     }));
   };
 
   forwardRef.displayName = 'Tooltip';
-  return React.forwardRef(forwardRef);
+  return /*#__PURE__*/React.forwardRef(forwardRef);
 })();
\ No newline at end of file
