@@ -1,4 +1,6 @@
 function _typeof(obj) {
+  "@babel/helpers - typeof";
+
   if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
     _typeof = function _typeof(obj) {
       return typeof obj;
@@ -34,22 +36,6 @@ function _createClass(Constructor, protoProps, staticProps) {
   return Constructor;
 }
 
-function _possibleConstructorReturn(self, call) {
-  if (call && (_typeof(call) === "object" || typeof call === "function")) {
-    return call;
-  }
-
-  return _assertThisInitialized(self);
-}
-
-function _assertThisInitialized(self) {
-  if (self === void 0) {
-    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
-  }
-
-  return self;
-}
-
 function _get(target, property, receiver) {
   if (typeof Reflect !== "undefined" && Reflect.get) {
     _get = Reflect.get;
@@ -80,13 +66,6 @@ function _superPropBase(object, property) {
   return object;
 }
 
-function _getPrototypeOf(o) {
-  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
-    return o.__proto__ || Object.getPrototypeOf(o);
-  };
-  return _getPrototypeOf(o);
-}
-
 function _inherits(subClass, superClass) {
   if (typeof superClass !== "function" && superClass !== null) {
     throw new TypeError("Super expression must either be null or a function");
@@ -111,26 +90,94 @@ function _setPrototypeOf(o, p) {
   return _setPrototypeOf(o, p);
 }
 
+function _createSuper(Derived) {
+  var hasNativeReflectConstruct = _isNativeReflectConstruct();
+
+  return function _createSuperInternal() {
+    var Super = _getPrototypeOf(Derived),
+        result;
+
+    if (hasNativeReflectConstruct) {
+      var NewTarget = _getPrototypeOf(this).constructor;
+
+      result = Reflect.construct(Super, arguments, NewTarget);
+    } else {
+      result = Super.apply(this, arguments);
+    }
+
+    return _possibleConstructorReturn(this, result);
+  };
+}
+
+function _possibleConstructorReturn(self, call) {
+  if (call && (_typeof(call) === "object" || typeof call === "function")) {
+    return call;
+  }
+
+  return _assertThisInitialized(self);
+}
+
+function _assertThisInitialized(self) {
+  if (self === void 0) {
+    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
+  }
+
+  return self;
+}
+
+function _isNativeReflectConstruct() {
+  if (typeof Reflect === "undefined" || !Reflect.construct) return false;
+  if (Reflect.construct.sham) return false;
+  if (typeof Proxy === "function") return true;
+
+  try {
+    Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {}));
+    return true;
+  } catch (e) {
+    return false;
+  }
+}
+
+function _getPrototypeOf(o) {
+  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
+    return o.__proto__ || Object.getPrototypeOf(o);
+  };
+  return _getPrototypeOf(o);
+}
+
 function _toConsumableArray(arr) {
-  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
+  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
 }
 
 function _nonIterableSpread() {
-  throw new TypeError("Invalid attempt to spread non-iterable instance");
+  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
+}
+
+function _unsupportedIterableToArray(o, minLen) {
+  if (!o) return;
+  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
+  var n = Object.prototype.toString.call(o).slice(8, -1);
+  if (n === "Object" && o.constructor) n = o.constructor.name;
+  if (n === "Map" || n === "Set") return Array.from(o);
+  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
 }
 
 function _iterableToArray(iter) {
-  if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
+  if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter);
 }
 
 function _arrayWithoutHoles(arr) {
-  if (Array.isArray(arr)) {
-    for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) {
-      arr2[i] = arr[i];
-    }
+  if (Array.isArray(arr)) return _arrayLikeToArray(arr);
+}
 
-    return arr2;
+function _arrayLikeToArray(arr, len) {
+  if (len == null || len > arr.length) len = arr.length;
+
+  for (var i = 0, arr2 = new Array(len); i < len; i++) {
+    arr2[i] = arr[i];
   }
+
+  return arr2;
 }
 /**
  * Copyright IBM Corp. 2016, 2018
@@ -245,10 +292,10 @@ var carbonFlatpickrMonthSelectPlugin = function carbonFlatpickrMonthSelectPlugin
   };
 };
 
-var DatePicker =
-/*#__PURE__*/
-function (_mixin) {
+var DatePicker = /*#__PURE__*/function (_mixin) {
   _inherits(DatePicker, _mixin);
+
+  var _super = _createSuper(DatePicker);
   /**
    * DatePicker.
    * @extends CreateComponent
@@ -258,12 +305,19 @@ function (_mixin) {
    */
 
 
+  /**
+   * DatePicker.
+   * @extends CreateComponent
+   * @extends InitComponentBySearch
+   * @extends Handles
+   * @param {HTMLElement} element The element working as an date picker.
+   */
   function DatePicker(element, options) {
     var _this;
 
     _classCallCheck(this, DatePicker);
 
-    _this = _possibleConstructorReturn(this, _getPrototypeOf(DatePicker).call(this, element, options));
+    _this = _super.call(this, element, options);
 
     _this._handleFocus = function () {
       if (_this.calendar) {
@@ -295,9 +349,11 @@ function (_mixin) {
         _this._rangeInput = rangeInput; // An attempt to open the date picker dropdown when this component gets focus,
         // and close the date picker dropdown when this component loses focus
 
+        // An attempt to open the date picker dropdown when this component gets focus,
+        // and close the date picker dropdown when this component loses focus
         var w = doc.defaultView;
-        var hasFocusin = 'onfocusin' in w;
-        var hasFocusout = 'onfocusout' in w;
+        var hasFocusin = ('onfocusin' in w);
+        var hasFocusout = ('onfocusout' in w);
         var focusinEventName = hasFocusin ? 'focusin' : 'focus';
         var focusoutEventName = hasFocusout ? 'focusout' : 'blur';
 
@@ -456,6 +512,8 @@ function (_mixin) {
       // as FlatPicker attempts to take over `keydown` event handler on `document` to run on the date picker dropdown.
 
 
+      // An attempt to temporarily set the `<input>` being edited as the one FlatPicker manages,
+      // as FlatPicker attempts to take over `keydown` event handler on `document` to run on the date picker dropdown.
       _this.manage(on(inputField, 'keydown', function (evt) {
         var origInput = _this.calendar._input;
         _this.calendar._input = evt.target;
@@ -541,6 +599,11 @@ function (_mixin) {
    */
 
 
+  /**
+   * Opens the date picker dropdown when this component gets focus.
+   * Used only for range mode for now.
+   * @private
+   */
   _createClass(DatePicker, [{
     key: "_rightArrowHTML",
     value: function _rightArrowHTML() {
@@ -564,6 +627,7 @@ function (_mixin) {
         } catch (err) {} // eslint-disable-line no-empty
 
 
+        // eslint-disable-line no-empty
         this.calendar = null;
       }
 
