@@ -1,4 +1,6 @@
 function _typeof(obj) {
+  "@babel/helpers - typeof";
+
   if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
     _typeof = function _typeof(obj) {
       return typeof obj;
@@ -34,29 +36,6 @@ function _createClass(Constructor, protoProps, staticProps) {
   return Constructor;
 }
 
-function _possibleConstructorReturn(self, call) {
-  if (call && (_typeof(call) === "object" || typeof call === "function")) {
-    return call;
-  }
-
-  return _assertThisInitialized(self);
-}
-
-function _assertThisInitialized(self) {
-  if (self === void 0) {
-    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
-  }
-
-  return self;
-}
-
-function _getPrototypeOf(o) {
-  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
-    return o.__proto__ || Object.getPrototypeOf(o);
-  };
-  return _getPrototypeOf(o);
-}
-
 function _inherits(subClass, superClass) {
   if (typeof superClass !== "function" && superClass !== null) {
     throw new TypeError("Super expression must either be null or a function");
@@ -80,6 +59,61 @@ function _setPrototypeOf(o, p) {
 
   return _setPrototypeOf(o, p);
 }
+
+function _createSuper(Derived) {
+  var hasNativeReflectConstruct = _isNativeReflectConstruct();
+
+  return function _createSuperInternal() {
+    var Super = _getPrototypeOf(Derived),
+        result;
+
+    if (hasNativeReflectConstruct) {
+      var NewTarget = _getPrototypeOf(this).constructor;
+
+      result = Reflect.construct(Super, arguments, NewTarget);
+    } else {
+      result = Super.apply(this, arguments);
+    }
+
+    return _possibleConstructorReturn(this, result);
+  };
+}
+
+function _possibleConstructorReturn(self, call) {
+  if (call && (_typeof(call) === "object" || typeof call === "function")) {
+    return call;
+  }
+
+  return _assertThisInitialized(self);
+}
+
+function _assertThisInitialized(self) {
+  if (self === void 0) {
+    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
+  }
+
+  return self;
+}
+
+function _isNativeReflectConstruct() {
+  if (typeof Reflect === "undefined" || !Reflect.construct) return false;
+  if (Reflect.construct.sham) return false;
+  if (typeof Proxy === "function") return true;
+
+  try {
+    Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {}));
+    return true;
+  } catch (e) {
+    return false;
+  }
+}
+
+function _getPrototypeOf(o) {
+  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
+    return o.__proto__ || Object.getPrototypeOf(o);
+  };
+  return _getPrototypeOf(o);
+}
 /**
  * Copyright IBM Corp. 2016, 2018
  *
@@ -100,10 +134,10 @@ var toArray = function toArray(arrayLike) {
   return Array.prototype.slice.call(arrayLike);
 };
 
-var Dropdown =
-/*#__PURE__*/
-function (_mixin) {
+var Dropdown = /*#__PURE__*/function (_mixin) {
   _inherits(Dropdown, _mixin);
+
+  var _super = _createSuper(Dropdown);
   /**
    * A selector with drop downs.
    * @extends CreateComponent
@@ -123,12 +157,29 @@ function (_mixin) {
    */
 
 
+  /**
+   * A selector with drop downs.
+   * @extends CreateComponent
+   * @extends InitComponentBySearch
+   * @extends TrackBlur
+   * @param {HTMLElement} element The element working as a selector.
+   * @param {object} [options] The component options.
+   * @param {string} [options.selectorItem] The CSS selector to find clickable areas in dropdown items.
+   * @param {string} [options.selectorItemSelected] The CSS selector to find the clickable area in the selected dropdown item.
+   * @param {string} [options.classSelected] The CSS class for the selected dropdown item.
+   * @param {string} [options.classOpen] The CSS class for the open state.
+   * @param {string} [options.classDisabled] The CSS class for the disabled state.
+   * @param {string} [options.eventBeforeSelected]
+   *   The name of the custom event fired before a drop down item is selected.
+   *   Cancellation of this event stops selection of drop down item.
+   * @param {string} [options.eventAfterSelected] The name of the custom event fired after a drop down item is selected.
+   */
   function Dropdown(element, options) {
     var _this;
 
     _classCallCheck(this, Dropdown);
 
-    _this = _possibleConstructorReturn(this, _getPrototypeOf(Dropdown).call(this, element, options));
+    _this = _super.call(this, element, options);
 
     _this.manage(on(_this.element.ownerDocument, 'click', function (event) {
       _this._toggle(event);
@@ -151,6 +202,11 @@ function (_mixin) {
     // the last hovered item if the user switches back to using the keyboard.
 
 
+    // When using the active descendant approach we use a class to give focus styles during keyboard (up/down arrows)
+    // navigation instead of relying on the :focus selector. This leaves the potential to have multiple items when
+    // switching interactions between keyboard and mouse users. To more closely align with Carbon React implementation,
+    // we want the focus class to move as the user hovers over items. This also updates the location of focus based on
+    // the last hovered item if the user switches back to using the keyboard.
     if ( // NOTE: `selectorTrigger` does NOT match the trigger button in older markup
     _this.element.querySelector(_this.options.selectorTrigger) && _this.element.querySelector(_this.options.selectorMenu)) {
       // Using the latest HTML structure that supports the aria-activedescendant attribute
@@ -171,6 +227,10 @@ function (_mixin) {
    */
 
 
+  /**
+   * Handles keydown event.
+   * @param {Event} event The event triggering this method.
+   */
   _createClass(Dropdown, [{
     key: "_handleKeyDown",
     value: function _handleKeyDown(event) {
@@ -210,6 +270,7 @@ function (_mixin) {
       // NOTE: `selectorTrigger` does NOT match the trigger button in older markup
       var triggerNode = this.element.querySelector(this.options.selectorTrigger); // only want to grab the listNode IF it's using the latest a11y HTML structure
 
+      // only want to grab the listNode IF it's using the latest a11y HTML structure
       var listNode = triggerNode ? this.element.querySelector(this.options.selectorMenu) : null;
 
       if (listNode) {
@@ -232,6 +293,7 @@ function (_mixin) {
       // NOTE: `selectorTrigger` does NOT match the trigger button in older markup
       var triggerNode = this.element.querySelector(this.options.selectorTrigger); // only want to grab the listNode IF it's using the latest a11y HTML structure
 
+      // only want to grab the listNode IF it's using the latest a11y HTML structure
       var listNode = triggerNode ? this.element.querySelector(this.options.selectorMenu) : null;
       var previouslyFocused = listNode.querySelector(this.options.selectorItemFocused);
       itemToFocus.classList.add(this.options.classFocused);
@@ -260,6 +322,7 @@ function (_mixin) {
       } // NOTE: `selectorTrigger` does NOT match the trigger button in older markup
 
 
+      // NOTE: `selectorTrigger` does NOT match the trigger button in older markup
       var triggerNode = this.element.querySelector(this.options.selectorTrigger);
 
       if ( // User presses down arrow
@@ -270,6 +333,7 @@ function (_mixin) {
         var isOpen = this.element.classList.contains(this.options.classOpen);
         var isOfSelf = this.element.contains(event.target); // Determine if the open className should be added, removed, or toggled
 
+        // Determine if the open className should be added, removed, or toggled
         var actions = {
           add: isOfSelf && event.which === 40 && !isOpen,
           remove: (!isOfSelf || event.which === 27) && isOpen,
@@ -285,8 +349,10 @@ function (_mixin) {
         });
         var listItems = toArray(this.element.querySelectorAll(this.options.selectorItem)); // only want to grab the listNode IF it's using the latest a11y HTML structure
 
+        // only want to grab the listNode IF it's using the latest a11y HTML structure
         var listNode = triggerNode ? this.element.querySelector(this.options.selectorMenu) : null; // @todo remove conditionals for elements existing once legacy structure is depreciated
 
+        // @todo remove conditionals for elements existing once legacy structure is depreciated
         if (changedState && this.element.classList.contains(this.options.classOpen)) {
           // toggled open
           if (triggerNode) {
@@ -316,6 +382,7 @@ function (_mixin) {
         } // @todo remove once legacy structure is depreciated
 
 
+        // @todo remove once legacy structure is depreciated
         if (!triggerNode) {
           listItems.forEach(function (item) {
             if (_this2.element.classList.contains(_this2.options.classOpen)) {
@@ -325,6 +392,12 @@ function (_mixin) {
             }
           });
         }
+
+        var menuListNode = this.element.querySelector(this.options.selectorMenu);
+
+        if (menuListNode) {
+          menuListNode.tabIndex = this.element.classList.contains(this.options.classOpen) ? '0' : '-1';
+        }
       }
     }
     /**
@@ -338,6 +411,9 @@ function (_mixin) {
       // @todo remove conditional once legacy structure is depreciated
       // NOTE: `selectorTrigger` does NOT match the trigger button in older markup
 
+      // Using the latest semantic markup structure where trigger is a button
+      // @todo remove conditional once legacy structure is depreciated
+      // NOTE: `selectorTrigger` does NOT match the trigger button in older markup
       if (this.element.querySelector(this.options.selectorTrigger)) {
         var listNode = this.element.querySelector(this.options.selectorMenu);
         var focusedId = listNode.getAttribute('aria-activedescendant');
@@ -371,6 +447,7 @@ function (_mixin) {
         }; // `items.indexOf(old)` may be -1 (Scenario of no previous focus)
 
 
+        // `items.indexOf(old)` may be -1 (Scenario of no previous focus)
         var index = Math.max(items.indexOf(old) + direction, -1);
         return items[handleUnderflow(handleOverflow(index, items.length), items.length)];
       };
@@ -460,7 +537,7 @@ function (_mixin) {
 
   }], [{
     key: "options",
-
+    get:
     /**
      * The component options.
      * If `options` is specified in the constructor, {@linkcode Dropdown.create .create()}, or {@linkcode Dropdown.init .init()},
@@ -491,7 +568,7 @@ function (_mixin) {
      *   Cancellation of this event stops selection of drop down item.
      * @property {string} [eventAfterSelected] The name of the custom event fired after a drop down item is selected.
      */
-    get: function get() {
+    function get() {
       var prefix = settings.prefix;
       return {
         selectorInit: '[data-dropdown]',
