@@ -19,7 +19,7 @@ function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { de
 var prefix = _carbonComponents.settings.prefix;
 describe('ListItem', function () {
   describe('Renders as expected', function () {
-    var item = (0, _enzyme.shallow)(_react.default.createElement(_ListItem.default, {
+    var item = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_ListItem.default, {
       className: "some-class"
     }, "An Item"));
     it('should render as an li element', function () {
