@@ -50,8 +50,8 @@ describe('NumberInput', function () {
           return undefined;
         }
       };
-      wrapper = (0, _enzyme.mount)(_react.default.createElement(_NumberInput.default, mockProps));
-      var iconTypes = [_iconsReact.CaretDownGlyph, _iconsReact.CaretUpGlyph];
+      wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_NumberInput.default, mockProps));
+      var iconTypes = [_iconsReact.Subtract16, _iconsReact.Add16];
       label = wrapper.find('label');
       numberInput = wrapper.find('input');
       container = wrapper.find(".".concat(prefix, "--number"));
@@ -146,7 +146,7 @@ describe('NumberInput', function () {
       });
       describe('initial rendering', function () {
         var getWrapper = function getWrapper(min, max, value) {
-          return (0, _enzyme.mount)(_react.default.createElement(_NumberInput.default, {
+          return (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_NumberInput.default, {
             min: min,
             max: max,
             value: value,
@@ -160,6 +160,19 @@ describe('NumberInput', function () {
           return wrapper.find('input');
         };
 
+        it('should correctly set defaultValue on uncontrolled input', function () {
+          var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_NumberInput.default, {
+            min: -1,
+            max: 100,
+            defaultValue: 10,
+            id: "test",
+            label: "Number Input",
+            className: "extra-class"
+          }));
+          var numberInput = getNumberInput(wrapper);
+          expect(wrapper.find('NumberInput').instance().state.value).toEqual(10);
+          expect(numberInput.prop('value')).toEqual(10);
+        });
         it('should set value as expected when value > min', function () {
           var wrapper = getWrapper(-1, 100, 0);
           var numberInput = getNumberInput(wrapper);
@@ -292,8 +305,8 @@ describe('NumberInput', function () {
         expect(wrapper.find('NumberInput').prop('iconDescription')).toEqual('choose a number');
       });
       it('should use correct icons', function () {
-        expect(icons.at(0).type()).toBe(_iconsReact.CaretUpGlyph);
-        expect(icons.at(1).type()).toBe(_iconsReact.CaretDownGlyph);
+        expect(icons.at(0).type()).toBe(_iconsReact.Subtract16);
+        expect(icons.at(1).type()).toBe(_iconsReact.Add16);
       });
       it('adds new iconDescription when passed via props', function () {
         wrapper.setProps({
@@ -323,14 +336,10 @@ describe('NumberInput', function () {
       });
       it('renders children as expected', function () {
         wrapper.setProps({
-          helperText: _react.default.createElement("span", null, "This helper text has ", _react.default.createElement("a", {
-            href: "#"
-          }, "a link"), ".")
+          helperText: /*#__PURE__*/_react.default.createElement("span", null, "This is helper text.")
         });
         var renderedHelper = wrapper.find(".".concat(prefix, "--form__helper-text"));
-        expect(renderedHelper.props().children).toEqual(_react.default.createElement("span", null, "This helper text has ", _react.default.createElement("a", {
-          href: "#"
-        }, "a link"), "."));
+        expect(renderedHelper.props().children).toEqual( /*#__PURE__*/_react.default.createElement("span", null, "This is helper text."));
       });
       it('should set helper text as expected', function () {
         wrapper.setProps({
@@ -344,7 +353,7 @@ describe('NumberInput', function () {
     describe('disabled numberInput', function () {
       var onClick = jest.fn();
       var onChange = jest.fn();
-      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_NumberInput.default, {
+      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_NumberInput.default, {
         id: "test",
         onClick: onClick,
         onChange: onChange,
@@ -380,7 +389,7 @@ describe('NumberInput', function () {
       beforeEach(function () {
         onClick = jest.fn();
         onChange = jest.fn();
-        wrapper = (0, _enzyme.mount)(_react.default.createElement(_NumberInput.default, {
+        wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_NumberInput.default, {
           id: "test",
           onClick: onClick,
           onChange: onChange,
@@ -388,17 +397,20 @@ describe('NumberInput', function () {
           max: 100
         }));
         input = wrapper.find('input');
-        upArrow = wrapper.find(_iconsReact.CaretUpGlyph).closest('button');
-        downArrow = wrapper.find(_iconsReact.CaretDownGlyph).closest('button');
+        upArrow = wrapper.find(_iconsReact.Add16).closest('button');
+        downArrow = wrapper.find(_iconsReact.Subtract16).closest('button');
       });
       it('should invoke onClick when numberInput is clicked', function () {
         input.simulate('click');
         expect(onClick).toBeCalled();
       });
       it('should invoke onClick when up arrow is clicked', function () {
+        wrapper.setProps({
+          value: 1
+        });
         upArrow.simulate('click');
         expect(onClick).toBeCalled();
-        expect(onClick).toHaveBeenCalledWith(expect.anything(), 'up');
+        expect(onClick).toHaveBeenCalledWith(expect.anything(), 'up', 2);
       });
       it('should only increase the value on up arrow click if value is less than max', function () {
         wrapper.setProps({
@@ -451,19 +463,19 @@ describe('NumberInput', function () {
         downArrow.simulate('click');
         expect(onClick).toBeCalled();
         expect(onChange).toBeCalled();
-        expect(onClick).toHaveBeenCalledWith(expect.anything(), 'down');
+        expect(onClick).toHaveBeenCalledWith(expect.anything(), 'down', 0);
       });
       it('should invoke onChange when numberInput is changed', function () {
         input.simulate('change');
         expect(onChange).toBeCalled();
-        expect(onChange).toHaveBeenCalledWith(expect.anything());
+        expect(onChange).toHaveBeenCalledWith(expect.anything(), expect.anything());
       });
     });
   });
 });
 describe('NumberInputSkeleton', function () {
   describe('Renders as expected', function () {
-    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_NumberInput2.default, null));
+    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_NumberInput2.default, null));
     var container = wrapper.find(".".concat(prefix, "--number"));
     var label = wrapper.find(".".concat(prefix, "--label"));
     it('has the expected classes', function () {
