@@ -18,7 +18,7 @@ function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { de
  */
 var prefix = _carbonComponents.settings.prefix;
 describe('SkeletonPlaceholder', function () {
-  var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SkeletonPlaceholder.default, null));
+  var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_SkeletonPlaceholder.default, null));
   it('Has the expected classes', function () {
     expect(wrapper.hasClass("".concat(prefix, "--skeleton__placeholder"))).toEqual(true);
   });
