@@ -19,7 +19,7 @@ function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { de
 var prefix = _carbonComponents.settings.prefix;
 describe('SkeletonText', function () {
   describe('Renders as expected', function () {
-    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SkeletonText.default, null));
+    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_SkeletonText.default, null));
     it('Has the expected classes', function () {
       expect(wrapper.hasClass("".concat(prefix, "--skeleton__text"))).toEqual(true);
     });
@@ -27,7 +27,7 @@ describe('SkeletonText', function () {
 });
 describe('SkeletonText Heading', function () {
   describe('Renders as expected', function () {
-    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SkeletonText.default, {
+    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_SkeletonText.default, {
       heading: true
     }));
     it('Has the expected classes', function () {
